@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -10,7 +10,6 @@
 #include "level_zero/core/source/driver/driver_handle.h"
 #include "level_zero/sysman/source/device/sysman_device.h"
 #include "level_zero/sysman/source/driver/sysman_driver.h"
-#include "level_zero/sysman/source/driver/sysman_driver_handle.h"
 #include "level_zero/sysman/source/driver/sysman_driver_handle_imp.h"
 #include "level_zero/tools/source/sysman/sysman.h"
 
@@ -244,6 +243,13 @@ ze_result_t ZE_APICALL zesDevicePciGetStats(
         [&]() { return L0::Sysman::SysmanDevice::pciGetStats(hDevice, pStats); });
 }
 
+ze_result_t ZE_APICALL zesDevicePciLinkSpeedUpdateExt(
+    zes_device_handle_t hDevice,
+    ze_bool_t shouldDowngrade,
+    zes_device_action_t *pendingAction) {
+    return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
+}
+
 ze_result_t ZE_APICALL zesDeviceEnumPowerDomains(
     zes_device_handle_t hDevice,
     uint32_t *pCount,
@@ -1321,6 +1327,13 @@ ZE_APIEXPORT ze_result_t ZE_APICALL zesDevicePciGetStats(
         pStats);
 }
 
+ZE_APIEXPORT ze_result_t ZE_APICALL zesDevicePciLinkSpeedUpdateExt(
+    zes_device_handle_t hDevice,
+    ze_bool_t shouldDowngrade,
+    zes_device_action_t *pendingAction) {
+    return L0::zesDevicePciLinkSpeedUpdateExt(hDevice, shouldDowngrade, pendingAction);
+}
+
 ZE_APIEXPORT ze_result_t ZE_APICALL zesDeviceEnumDiagnosticTestSuites(
     zes_device_handle_t hDevice,
     uint32_t *pCount,
