@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,8 +16,8 @@
 #include "shared/source/utilities/tag_allocator.h"
 
 #include "level_zero/core/source/cmdqueue/cmdqueue_imp.h"
-#include "level_zero/core/source/device/device_imp.h"
-#include "level_zero/core/source/driver/driver_handle_imp.h"
+#include "level_zero/core/source/device/device.h"
+#include "level_zero/core/source/driver/driver_handle.h"
 #include "level_zero/core/source/event/event.h"
 #include "level_zero/core/source/kernel/kernel.h"
 #include "level_zero/core/source/kernel/kernel_imp.h"
@@ -120,7 +120,7 @@ NEO::GraphicsAllocation *CommandList::getAllocationFromHostPtrMap(const void *bu
         auto allocation = csr->getInternalAllocationStorage()->obtainTemporaryAllocationWithPtr(bufferSize, buffer, NEO::AllocationType::externalHostPtr);
         if (allocation != nullptr) {
             auto alloc = allocation.get();
-            alloc->hostPtrTaskCountAssignment++;
+            alloc->incrementHostPtrTaskCountAssignment();
             csr->getInternalAllocationStorage()->storeAllocationWithTaskCount(std::move(allocation), NEO::AllocationUsage::TEMPORARY_ALLOCATION, csr->peekTaskCount());
             return alloc;
         }
@@ -138,7 +138,7 @@ NEO::GraphicsAllocation *CommandList::getHostPtrAlloc(const void *buffer, uint64
         return nullptr;
     }
     if (isImmediateType()) {
-        alloc->hostPtrTaskCountAssignment++;
+        alloc->incrementHostPtrTaskCountAssignment();
         auto csr = getCsr(copyOffload);
         csr->getInternalAllocationStorage()->storeAllocationWithTaskCount(std::unique_ptr<NEO::GraphicsAllocation>(alloc), NEO::AllocationUsage::TEMPORARY_ALLOCATION, csr->peekTaskCount());
     } else if (alloc->getAllocationType() == NEO::AllocationType::externalHostPtr) {
@@ -189,11 +189,10 @@ void CommandList::eraseResidencyContainerEntry(NEO::GraphicsAllocation *allocati
 }
 
 void CommandList::migrateSharedAllocations() {
-    auto deviceImp = static_cast<DeviceImp *>(device);
-    DriverHandleImp *driverHandleImp = static_cast<DriverHandleImp *>(deviceImp->getDriverHandle());
-    std::lock_guard<std::mutex> lock(driverHandleImp->sharedMakeResidentAllocationsLock);
-    auto pageFaultManager = device->getDriverHandle()->getMemoryManager()->getPageFaultManager();
-    for (auto &alloc : driverHandleImp->sharedMakeResidentAllocations) {
+    auto driverHandle = device->getDriverHandle();
+    std::lock_guard<std::mutex> lock(driverHandle->sharedMakeResidentAllocationsLock);
+    auto pageFaultManager = driverHandle->getMemoryManager()->getPageFaultManager();
+    for (auto &alloc : driverHandle->sharedMakeResidentAllocations) {
         pageFaultManager->moveAllocationToGpuDomain(reinterpret_cast<void *>(alloc.second->getGpuAddress()));
     }
     if (this->unifiedMemoryControls.indirectSharedAllocationsAllowed) {
