@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -502,8 +502,7 @@ struct CommandList : _ze_command_list_handle_t {
 
     template <CaptureApi api, typename... TArgs>
     ze_result_t capture(TArgs... apiArgs) {
-        return this->isImmediateType() ? L0::captureCommand<api>(*this, this->captureTarget, apiArgs...)
-                                       : ZE_RESULT_ERROR_NOT_AVAILABLE;
+        return L0::captureCommand<api>(*this, this->captureTarget, apiArgs...);
     }
 
     inline bool getIsWalkerWithProfilingEnqueued() {
@@ -518,6 +517,11 @@ struct CommandList : _ze_command_list_handle_t {
     uint32_t getFrontEndPatchListCount() const {
         return frontEndPatchListCount;
     }
+
+    uint32_t getHostFunctionPatchListCount() const {
+        return hostFunctionPatchListCount;
+    }
+
     size_t getTotalNoopSpace() const {
         return totalNoopSpace;
     }
@@ -640,6 +644,7 @@ struct CommandList : _ze_command_list_handle_t {
     uint32_t maxLocalSubRegionSize = 0;
     uint32_t frontEndPatchListCount = 0;
     uint32_t activeScratchPatchElements = 0;
+    uint32_t hostFunctionPatchListCount = 0;
 
     bool isSyncModeQueue = false;
     bool isTbxMode = false;
