@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -44,6 +44,7 @@ static_assert(sizeof(EventData) == (3 * sizeof(uint64_t)),
               "This structure is consumed by GPU and has to follow specific restrictions for padding and size");
 
 struct AlignedAllocationData {
+    NEO::SvmAllocationData *svmAllocData = nullptr;
     uintptr_t alignedAllocationPtr = 0u;
     size_t offset = 0u;
     NEO::GraphicsAllocation *alloc = nullptr;
@@ -356,13 +357,12 @@ struct CommandListCoreFamily : public CommandListImp {
     size_t getTotalSizeForCopyRegion(const ze_copy_region_t *region, uint32_t pitch, uint32_t slicePitch);
     bool isAppendSplitNeeded(void *dstPtr, const void *srcPtr, size_t size, NEO::TransferDirection &directionOut);
     bool isAppendSplitNeeded(NEO::MemoryPool dstPool, NEO::MemoryPool srcPool, size_t size, NEO::TransferDirection &directionOut, bool remoteCopy);
-    bool isAppendSplitRemote(NEO::SvmAllocationData *allocData, void *ptr) const;
+    bool isRemoteAlloc(NEO::SvmAllocationData *allocData) const;
 
     void applyMemoryRangesBarrier(uint32_t numRanges, const size_t *pRangeSizes,
                                   const void **pRanges);
 
     ze_result_t programSyncBuffer(Kernel &kernel, NEO::Device &device, const ze_group_count_t &threadGroupDimensions, size_t &patchIndex);
-    void programRegionGroupBarrier(Kernel &kernel, const ze_group_count_t &threadGroupDimensions, size_t localRegionSize, size_t &patchIndex);
     void appendWriteKernelTimestamp(Event *event, CommandToPatchContainer *outTimeStampSyncCmds, bool beforeWalker, bool maskLsb, bool workloadPartition, bool copyOperation);
     void adjustWriteKernelTimestamp(uint64_t address, uint64_t baseAddress, CommandToPatchContainer *outTimeStampSyncCmds, bool workloadPartition, bool copyOperation, bool globalTimestamp);
     void writeTimestamp(NEO::CommandContainer &container, uint32_t regOffset, uint64_t address, bool maskLsb, bool workloadPartition, void **postSyncCmdBuffer, bool copyOperation);
@@ -443,7 +443,7 @@ struct CommandListCoreFamily : public CommandListImp {
     bool singleEventPacketRequired(bool inputSinglePacketEventRequest) const;
     void programEventL3Flush(Event *event);
     virtual ze_result_t flushInOrderCounterSignal() { return ZE_RESULT_SUCCESS; };
-    bool isCopyOffloadAllowed(const NEO::GraphicsAllocation *srcAllocation, const NEO::GraphicsAllocation *dstAllocation, bool imageToBuffer) const;
+    bool isCopyOffloadAllowed(const NEO::GraphicsAllocation *srcAllocation, const NEO::GraphicsAllocation *dstAllocation, bool imageToBuffer, bool remoteCopy) const;
     bool isSharedSystemEnabled() const;
     void emitMemAdviseForSystemCopy(const AlignedAllocationData &allocationStruct, size_t size);
     void setAdditionalKernelLaunchParams(CmdListKernelLaunchParams &launchParams, Kernel &kernel) const;
@@ -475,8 +475,9 @@ struct CommandListCoreFamily : public CommandListImp {
 
     NEO::InOrderPatchCommandsContainer<GfxFamily> inOrderPatchCmds;
 
-    bool latestOperationHasOptimizedCbEvent = false;
+    bool latestOperationHasHeapfullCbEventWithProfiling = false;
     bool latestOperationRequiredNonWalkerInOrderCmdsChaining = false;
+    bool isPostSyncSkippedOnLatestInOrderOperation = false;
     bool duplicatedInOrderCounterStorageEnabled = false;
     bool inOrderAtomicSignalingEnabled = false;
     bool allowCbWaitEventsNoopDispatch = false;
@@ -485,6 +486,7 @@ struct CommandListCoreFamily : public CommandListImp {
     bool useAdditionalBlitProperties = false;
     bool isPostImageWriteFlushRequired = false;
     bool latestFlushIsDualCopyOffload = false;
+    bool isWalkerPostSyncSkipEnabled = false;
 };
 
 template <PRODUCT_FAMILY gfxProductFamily>
