@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,12 +21,13 @@
 #include "shared/source/memory_manager/memory_manager.h"
 #include "shared/source/os_interface/os_context.h"
 #include "shared/source/os_interface/product_helper.h"
+#include "shared/source/utilities/buffer_pool_allocator.inl"
+#include "shared/source/utilities/command_buffer_pool_allocator.h"
 
 #include "level_zero/core/source/cmdlist/cmdlist_imp.h"
 #include "level_zero/core/source/cmdqueue/cmdqueue_imp.h"
 #include "level_zero/core/source/device/device.h"
-#include "level_zero/core/source/device/device_imp.h"
-#include "level_zero/core/source/driver/driver_handle_imp.h"
+#include "level_zero/core/source/driver/driver_handle.h"
 #include "level_zero/core/source/gfx_core_helpers/l0_gfx_core_helper.h"
 #include "level_zero/core/source/helpers/properties_parser.h"
 #include "level_zero/core/source/kernel/kernel.h"
@@ -106,7 +107,7 @@ ze_result_t CommandQueueImp::initialize(bool copyOnly, bool isInternal, bool imm
         auto &productHelper = rootDeviceEnvironment.getHelper<NEO::ProductHelper>();
         this->doubleSbaWa = productHelper.isAdditionalStateBaseAddressWARequired(hwInfo);
         this->cmdListHeapAddressModel = L0GfxCoreHelper::getHeapAddressModel(rootDeviceEnvironment);
-        this->dispatchCmdListBatchBufferAsPrimary = L0GfxCoreHelper::dispatchCmdListBatchBufferAsPrimary(!(internalUsage && immediateCmdListQueue));
+        this->dispatchCmdListBatchBufferAsPrimary = L0GfxCoreHelper::dispatchCmdListBatchBufferAsPrimary(true);
         auto &compilerProductHelper = rootDeviceEnvironment.getHelper<NEO::CompilerProductHelper>();
         this->heaplessModeEnabled = compilerProductHelper.isHeaplessModeEnabled(hwInfo);
         this->heaplessStateInitEnabled = compilerProductHelper.isHeaplessStateInitEnabled(this->heaplessModeEnabled);
@@ -129,7 +130,7 @@ NEO::WaitStatus CommandQueueImp::reserveLinearStreamSize(size_t size) {
     return waitStatus;
 }
 
-NEO::SubmissionStatus CommandQueueImp::submitBatchBuffer(size_t offset, NEO::ResidencyContainer &residencyContainer, void *endingCmdPtr,
+NEO::SubmissionStatus CommandQueueImp::submitBatchBuffer(size_t offset, void *endingCmdPtr,
                                                          bool isCooperative) {
     UNRECOVERABLE_IF(csr == nullptr);
 
@@ -202,7 +203,7 @@ ze_result_t CommandQueueImp::synchronizeByPollingForTaskCount(uint64_t timeoutNa
 
 void CommandQueueImp::printKernelsPrintfOutput(bool hangDetected) {
     for (auto &kernelWeakPtr : this->printfKernelContainer) {
-        std::lock_guard<std::mutex> lock(static_cast<DeviceImp *>(this->getDevice())->printfKernelMutex);
+        std::lock_guard<std::mutex> lock(this->getDevice()->printfKernelMutex);
         if (!kernelWeakPtr.expired()) {
             kernelWeakPtr.lock()->printPrintfOutput(hangDetected);
         }
@@ -253,12 +254,12 @@ CommandQueue *CommandQueue::create(uint32_t productFamily, Device *device, NEO::
     }
 
     auto &osContext = csr->getOsContext();
-    DriverHandleImp *driverHandleImp = static_cast<DriverHandleImp *>(device->getDriverHandle());
-    if (driverHandleImp->powerHint && driverHandleImp->powerHint != osContext.getUmdPowerHintValue()) {
+    auto driverHandle = device->getDriverHandle();
+    if (driverHandle->powerHint && driverHandle->powerHint != osContext.getUmdPowerHintValue()) {
         csr->unregisterDirectSubmissionFromController();
         auto lock = csr->obtainUniqueOwnership();
         csr->resetDirectSubmission();
-        osContext.setUmdPowerHintValue(driverHandleImp->powerHint);
+        osContext.setUmdPowerHintValue(driverHandle->powerHint);
         osContext.reInitializeContext();
     }
 
@@ -281,41 +282,69 @@ void CommandQueueImp::registerCsrClient() {
 
 ze_result_t CommandQueueImp::CommandBufferManager::initialize(Device *device, size_t sizeRequested) {
     size_t alignedSize = alignUp<size_t>(sizeRequested, MemoryConstants::pageSize64k);
+
+    auto &rootDeviceEnvironment = device->getNEODevice()->getRootDeviceEnvironment();
+    auto &productHelper = rootDeviceEnvironment.getHelper<NEO::ProductHelper>();
+
+    if (auto forceEnable = NEO::debugManager.flags.EnableCommandBufferPoolAllocator.get();
+        (forceEnable == 1) || (forceEnable == -1 && productHelper.is2MBLocalMemAlignmentEnabled())) {
+        auto &poolAllocator = device->getNEODevice()->getCommandBufferPoolAllocator();
+        buffers[BufferAllocation::first] = poolAllocator.allocateCommandBuffer(alignedSize);
+        buffers[BufferAllocation::second] = poolAllocator.allocateCommandBuffer(alignedSize);
+    }
+
     NEO::AllocationProperties properties{device->getRootDeviceIndex(), true, alignedSize,
                                          NEO::AllocationType::commandBuffer,
                                          (device->getNEODevice()->getNumGenericSubDevices() > 1u) /* multiOsContextCapable */,
                                          false,
                                          device->getNEODevice()->getDeviceBitfield()};
 
-    auto firstBuffer = device->obtainReusableAllocation(alignedSize, NEO::AllocationType::commandBuffer);
-    if (!firstBuffer) {
-        firstBuffer = device->getNEODevice()->getMemoryManager()->allocateGraphicsMemoryWithProperties(properties);
+    if (!buffers[BufferAllocation::first]) {
+        buffers[BufferAllocation::first] = device->obtainReusableAllocation(alignedSize, NEO::AllocationType::commandBuffer);
+        if (!buffers[BufferAllocation::first]) {
+            buffers[BufferAllocation::first] = device->getNEODevice()->getMemoryManager()->allocateGraphicsMemoryWithProperties(properties);
+        }
     }
 
-    auto secondBuffer = device->obtainReusableAllocation(alignedSize, NEO::AllocationType::commandBuffer);
-    if (!secondBuffer) {
-        secondBuffer = device->getNEODevice()->getMemoryManager()->allocateGraphicsMemoryWithProperties(properties);
+    if (!buffers[BufferAllocation::second]) {
+        buffers[BufferAllocation::second] = device->obtainReusableAllocation(alignedSize, NEO::AllocationType::commandBuffer);
+        if (!buffers[BufferAllocation::second]) {
+            buffers[BufferAllocation::second] = device->getNEODevice()->getMemoryManager()->allocateGraphicsMemoryWithProperties(properties);
+        }
     }
 
-    buffers[BufferAllocation::first] = firstBuffer;
-    buffers[BufferAllocation::second] = secondBuffer;
-
     if (!buffers[BufferAllocation::first] || !buffers[BufferAllocation::second]) {
         return ZE_RESULT_ERROR_OUT_OF_DEVICE_MEMORY;
     }
 
     flushId[BufferAllocation::first] = std::make_pair(0u, 0u);
     flushId[BufferAllocation::second] = std::make_pair(0u, 0u);
+
     return ZE_RESULT_SUCCESS;
 }
 
 void CommandQueueImp::CommandBufferManager::destroy(Device *device) {
-    if (buffers[BufferAllocation::first]) {
-        device->storeReusableAllocation(*buffers[BufferAllocation::first]);
+    auto &poolAllocator = device->getNEODevice()->getCommandBufferPoolAllocator();
+
+    if (auto firstBA = buffers[BufferAllocation::first]) {
+        if (firstBA->getParentAllocation() &&
+            poolAllocator.isPoolBuffer(firstBA->getParentAllocation())) {
+            DEBUG_BREAK_IF(!firstBA->isView());
+            poolAllocator.freeCommandBuffer(firstBA);
+        } else {
+            device->storeReusableAllocation(*firstBA);
+        }
         buffers[BufferAllocation::first] = nullptr;
     }
-    if (buffers[BufferAllocation::second]) {
-        device->storeReusableAllocation(*buffers[BufferAllocation::second]);
+
+    if (auto secondBA = buffers[BufferAllocation::second]) {
+        if (secondBA->getParentAllocation() &&
+            poolAllocator.isPoolBuffer(secondBA->getParentAllocation())) {
+            DEBUG_BREAK_IF(!secondBA->isView());
+            poolAllocator.freeCommandBuffer(secondBA);
+        } else {
+            device->storeReusableAllocation(*secondBA);
+        }
         buffers[BufferAllocation::second] = nullptr;
     }
 }
