@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -18,6 +18,7 @@ class ScratchSpaceController;
 } // namespace NEO
 
 namespace L0 {
+struct CommandListExecutionContext;
 
 template <GFXCORE_FAMILY gfxCoreFamily>
 struct CommandQueueHw : public CommandQueueImp {
@@ -34,13 +35,6 @@ struct CommandQueueHw : public CommandQueueImp {
     size_t estimateStateBaseAddressCmdSize();
     MOCKABLE_VIRTUAL void programFrontEnd(uint64_t scratchAddress, uint32_t perThreadScratchSpaceSlot0Size, NEO::LinearStream &commandStream, NEO::StreamProperties &streamProperties);
 
-    MOCKABLE_VIRTUAL size_t estimateFrontEndCmdSizeForMultipleCommandLists(bool &isFrontEndStateDirty, CommandList *commandList,
-                                                                           NEO::StreamProperties &csrState,
-                                                                           const NEO::StreamProperties &cmdListRequired,
-                                                                           const NEO::StreamProperties &cmdListFinal,
-                                                                           NEO::StreamProperties &requiredState,
-                                                                           bool &propertyDirty,
-                                                                           bool &frontEndReturnPoint);
     size_t estimateFrontEndCmdSize();
     size_t estimateFrontEndCmdSize(bool isFrontEndDirty);
 
@@ -58,71 +52,13 @@ struct CommandQueueHw : public CommandQueueImp {
                        void **patchPreambleBuffer);
 
   protected:
-    struct CommandListExecutionContext {
-
-        CommandListExecutionContext() {}
-
-        CommandListExecutionContext(ze_command_list_handle_t *commandListHandles,
-                                    uint32_t numCommandLists,
-                                    NEO::PreemptionMode contextPreemptionMode,
-                                    Device *device,
-                                    NEO::ScratchSpaceController *scratchSpaceController,
-                                    NEO::GraphicsAllocation *globalStatelessAllocation,
-                                    bool debugEnabled,
-                                    bool programActivePartitionConfig,
-                                    bool performMigration,
-                                    bool sipSent);
-
-        inline bool isNEODebuggerActive(Device *device);
-
-        NEO::StreamProperties cmdListBeginState{};
-        uint64_t scratchGsba = 0;
-        uint64_t childGpuAddressPositionBeforeDynamicPreamble = 0;
-        uint64_t currentGpuAddressForChainedBbStart = 0;
-
-        size_t spaceForResidency = 10;
-        size_t bufferSpaceForPatchPreamble = 0;
-        size_t totalNoopSpaceForPatchPreamble = 0;
-        CommandList *firstCommandList = nullptr;
-        CommandList *lastCommandList = nullptr;
-        void *currentPatchForChainedBbStart = nullptr;
-        void *currentPatchPreambleBuffer = nullptr;
-        uintptr_t basePatchPreambleAddress = 0;
-        NEO::ScratchSpaceController *scratchSpaceController = nullptr;
-        NEO::GraphicsAllocation *globalStatelessAllocation = nullptr;
-        std::unique_lock<std::mutex> *outerLockForIndirect = nullptr;
-        std::unique_lock<NEO::CommandStreamReceiver::MutexType> *lockCSR = nullptr;
-
-        NEO::PreemptionMode preemptionMode{};
-        NEO::PreemptionMode statePreemption{};
-        uint32_t perThreadScratchSpaceSlot0Size = 0;
-        uint32_t perThreadScratchSpaceSlot1Size = 0;
-        uint32_t totalActiveScratchPatchElements = 0;
-        UnifiedMemoryControls unifiedMemoryControls{};
-
-        bool anyCommandListWithCooperativeKernels = false;
-        bool anyCommandListRequiresDisabledEUFusion = false;
-        bool cachedMOCSAllowed = true;
-        bool containsAnyRegularCmdList = false;
-        bool gsbaStateDirty = false;
+    struct EstimateRegularHeapfulPerCmdlistData {
+        CommandListRequiredStateChange cmdListState;
         bool frontEndStateDirty = false;
-        const bool isPreemptionModeInitial{false};
-        bool isDevicePreemptionModeMidThread{};
-        bool isDebugEnabled{};
-        bool stateSipRequired{};
-        bool isProgramActivePartitionConfigRequired{};
-        bool isMigrationRequested{};
-        bool isDirectSubmissionEnabled{};
-        bool isDispatchTaskCountPostSyncRequired{};
-        bool hasIndirectAccess{};
-        bool rtDispatchRequired = false;
-        bool globalInit = false;
-        bool lockScratchController = false;
-        bool cmdListScratchAddressPatchingEnabled = false;
-        bool containsParentImmediateStream = false;
-        bool patchPreambleWaitSyncNeeded = false;
+        bool gpgpuEnabled = false;
+        bool baseAddressStateDirty = false;
+        bool scmStateDirty = false;
     };
-
     inline void processMemAdviseOperations(CommandList *commandList);
 
     ze_result_t executeCommandListsRegularHeapless(CommandListExecutionContext &ctx,
@@ -151,19 +87,26 @@ struct CommandQueueHw : public CommandQueueImp {
                                                      ze_fence_handle_t hFence,
                                                      NEO::LinearStream *parentImmediateCommandlistLinearStream);
     MOCKABLE_VIRTUAL bool isDispatchTaskCountPostSyncRequired(ze_fence_handle_t hFence, bool containsAnyRegularCmdList, bool containsParentImmediateStream) const;
-    inline size_t estimateLinearStreamSizeInitial(CommandListExecutionContext &ctx);
-    size_t estimateStreamSizeForExecuteCommandListsRegularHeapless(CommandListExecutionContext &ctx,
-                                                                   uint32_t numCommandLists,
-                                                                   ze_command_list_handle_t *commandListHandles,
-                                                                   bool instructionCacheFlushRequired,
-                                                                   bool stateCacheFlushRequired);
+    inline size_t estimateLinearStreamSizeTotal(CommandListExecutionContext &ctx,
+                                                ze_command_list_handle_t *commandListHandles,
+                                                uint32_t numCommandLists);
+    inline size_t estimateLinearStreamSizeSharedPerCmdList(CommandListExecutionContext &ctx,
+                                                           CommandList *commandList);
+    inline size_t estimateLinearStreamSizeRegularHeapfulPerCmdList(CommandListExecutionContext &ctx,
+                                                                   CommandList *commandList,
+                                                                   uint32_t index,
+                                                                   EstimateRegularHeapfulPerCmdlistData &sharedData,
+                                                                   NEO::StreamProperties &csrStreamProperties);
+    inline size_t estimateLinearStreamSizeRegularHeapfulPostCmdList(CommandListExecutionContext &ctx);
+    inline size_t estimateLinearStreamSizeSharedPostCmdList(CommandListExecutionContext &ctx, uint32_t numCommandLists);
+    inline size_t estimateLinearStreamSizeSharedInitial(CommandListExecutionContext &ctx);
     inline size_t estimateCommandListSecondaryStart(CommandList *commandList);
     inline size_t estimateCommandListPrimaryStart(bool required);
-    inline size_t estimateCommandListPatchPreamble(CommandListExecutionContext &ctx, uint32_t numCommandLists);
     inline size_t estimateCommandListPatchPreambleFrontEndCmd(CommandListExecutionContext &ctx, CommandList *commandList);
     inline void getCommandListPatchPreambleData(CommandListExecutionContext &ctx, CommandList *commandList);
     size_t estimateCommandListPatchPreambleWaitSync(CommandListExecutionContext &ctx, CommandList *commandList);
-    inline size_t estimateTotalPatchPreambleData(CommandListExecutionContext &ctx);
+    size_t estimateCommandListPatchPreambleHostFunctions(CommandListExecutionContext &ctx, CommandList *commandList);
+    inline size_t estimateTotalCommandListPatchPreambleData(CommandListExecutionContext &ctx, uint32_t numCommandLists);
     inline void retrivePatchPreambleSpace(CommandListExecutionContext &ctx, NEO::LinearStream &commandStream);
     inline void dispatchPatchPreambleEnding(CommandListExecutionContext &ctx);
     inline void dispatchPatchPreambleInOrderNoop(CommandListExecutionContext &ctx, CommandList *commandList);
@@ -171,9 +114,6 @@ struct CommandQueueHw : public CommandQueueImp {
     inline size_t estimateCommandListResidencySize(CommandList *commandList);
     inline void setFrontEndStateProperties(CommandListExecutionContext &ctx);
     inline void handleScratchSpaceAndUpdateGSBAStateDirtyFlag(CommandListExecutionContext &ctx);
-    inline size_t estimateLinearStreamSizeComplementary(CommandListExecutionContext &ctx,
-                                                        ze_command_list_handle_t *phCommandLists,
-                                                        uint32_t numCommandLists);
     MOCKABLE_VIRTUAL ze_result_t makeAlignedChildStreamAndSetGpuBase(NEO::LinearStream &child, size_t requiredSize, CommandListExecutionContext &ctx);
     inline void getGlobalFenceAndMakeItResident();
     inline void getWorkPartitionAndMakeItResident();
@@ -195,6 +135,13 @@ struct CommandQueueHw : public CommandQueueImp {
     inline void makeRayTracingBufferResident(NEO::GraphicsAllocation *rtBuffer);
 
     inline void programActivePartitionConfig(bool isProgramActivePartitionConfigRequired, NEO::LinearStream &commandStream);
+    size_t estimateFrontEndCmdSizeForMultipleCommandLists(bool &isFrontEndStateDirty, CommandList *commandList,
+                                                          NEO::StreamProperties &csrState,
+                                                          const NEO::StreamProperties &cmdListRequired,
+                                                          const NEO::StreamProperties &cmdListFinal,
+                                                          NEO::StreamProperties &requiredState,
+                                                          bool &propertyDirty,
+                                                          bool &frontEndReturnPoint);
     inline void programOneCmdListFrontEndIfDirty(CommandListExecutionContext &ctx,
                                                  NEO::LinearStream &commandStream,
                                                  CommandListRequiredStateChange &cmdListRequiredState);
@@ -222,7 +169,7 @@ struct CommandQueueHw : public CommandQueueImp {
                                            ze_command_list_handle_t *commandListHandles);
     ze_result_t waitForCommandQueueCompletion(CommandListExecutionContext &ctx);
     inline ze_result_t handleNonParentImmediateStream(ze_fence_handle_t hFence, CommandListExecutionContext &ctx, uint32_t numCommandLists,
-                                                      ze_command_list_handle_t *phCommandLists, NEO::LinearStream *streamForDispatch, bool isFenceRequired);
+                                                      ze_command_list_handle_t *phCommandLists, NEO::LinearStream *streamForDispatch);
     inline ze_result_t handleSubmission(NEO::SubmissionStatus submitRet);
     inline size_t estimatePipelineSelectCmdSizeForMultipleCommandLists(NEO::StreamProperties &csrState,
                                                                        const NEO::StreamProperties &cmdListRequired,
@@ -269,6 +216,8 @@ struct CommandQueueHw : public CommandQueueImp {
     inline void programRequiredStateBaseAddressForCommandList(CommandListExecutionContext &ctx,
                                                               NEO::LinearStream &commandStream,
                                                               CommandListRequiredStateChange &cmdListRequired);
+    inline void programRequiredCacheFlushes(CommandListExecutionContext &ctx,
+                                            NEO::LinearStream &commandStream);
     inline void updateBaseAddressState(CommandList *lastCommandList);
     inline void updateDebugSurfaceState(CommandListExecutionContext &ctx);
     inline void patchCommands(CommandList &commandList, CommandListExecutionContext &ctx);
