@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -27,7 +27,7 @@ class Device;
 }
 
 namespace L0 {
-struct DriverHandle;
+class DriverHandle;
 struct Image;
 
 class ContextExt;
