@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,8 @@
 #include "shared/source/utilities/cpu_info.h"
 
 #include "level_zero/core/source/cmdlist/cmdlist.h"
-#include "level_zero/core/source/device/device_imp.h"
-#include "level_zero/core/source/driver/driver_handle_imp.h"
+#include "level_zero/core/source/device/device.h"
+#include "level_zero/core/source/driver/driver_handle.h"
 #include "level_zero/core/source/event/event.h"
 #include "level_zero/core/source/gfx_core_helpers/l0_gfx_core_helper.h"
 #include "level_zero/core/source/helpers/properties_parser.h"
@@ -48,10 +48,8 @@ ze_result_t ContextImp::destroy() {
 }
 
 ze_result_t ContextImp::getStatus() {
-    DriverHandleImp *driverHandleImp = static_cast<DriverHandleImp *>(this->driverHandle);
-    for (auto &device : driverHandleImp->devices) {
-        DeviceImp *deviceImp = static_cast<DeviceImp *>(device);
-        if (deviceImp->resourcesReleased) {
+    for (auto device : this->driverHandle->devices) {
+        if (device->resourcesReleased) {
             return ZE_RESULT_ERROR_DEVICE_LOST;
         }
     }
@@ -63,7 +61,7 @@ DriverHandle *ContextImp::getDriverHandle() {
 }
 
 ContextImp::ContextImp(DriverHandle *driverHandle) {
-    this->driverHandle = static_cast<DriverHandleImp *>(driverHandle);
+    this->driverHandle = driverHandle;
     this->contextExt = createContextExt(driverHandle);
 
     // Determine context settings based on device capabilities.
@@ -462,12 +460,10 @@ ze_result_t ContextImp::allocSharedMem(ze_device_handle_t hDevice,
 }
 
 void ContextImp::freePeerAllocations(const void *ptr, bool blocking, Device *device) {
-    DeviceImp *deviceImp = static_cast<DeviceImp *>(device);
+    std::unique_lock<NEO::SpinLock> lock(device->peerAllocations.mutex);
 
-    std::unique_lock<NEO::SpinLock> lock(deviceImp->peerAllocations.mutex);
-
-    auto iter = deviceImp->peerAllocations.allocations.find(ptr);
-    if (iter != deviceImp->peerAllocations.allocations.end()) {
+    auto iter = device->peerAllocations.allocations.find(ptr);
+    if (iter != device->peerAllocations.allocations.end()) {
         auto peerAllocData = &iter->second;
         auto peerAlloc = peerAllocData->gpuAllocations.getDefaultGraphicsAllocation();
         auto peerPtr = reinterpret_cast<void *>(peerAlloc->getGpuAddress());
@@ -479,14 +475,20 @@ void ContextImp::freePeerAllocations(const void *ptr, bool blocking, Device *dev
         } else {
             this->driverHandle->svmAllocsManager->freeSVMAlloc(peerPtr, blocking);
         }
-        deviceImp->peerAllocations.allocations.erase(iter);
+        device->peerAllocations.allocations.erase(iter);
     }
 
-    for (auto &subDevice : deviceImp->subDevices) {
+    for (auto &subDevice : device->subDevices) {
         this->freePeerAllocations(ptr, blocking, subDevice);
     }
 }
 
+void ContextImp::freePeerAllocationsFromAll(const void *ptr, bool blocking) {
+    for (auto &pairDevice : this->devices) {
+        this->freePeerAllocations(ptr, blocking, Device::fromHandle(pairDevice.second));
+    }
+}
+
 NEO::UsmMemAllocPool *ContextImp::getUsmPoolOwningPtr(const void *ptr, NEO::SvmAllocationData *svmData) {
     DEBUG_BREAK_IF(nullptr == svmData);
     NEO::UsmMemAllocPool *usmPool = nullptr;
@@ -552,6 +554,9 @@ ze_result_t ContextImp::freeMem(const void *ptr, bool blocking) {
             if (ipcHandleIterator->second->refcnt == 0 || nullptr == usmPool) {
                 auto *memoryManager = driverHandle->getMemoryManager();
                 memoryManager->closeInternalHandle(ipcHandleIterator->second->handle, ipcHandleIterator->second->handleId, ipcHandleIterator->second->alloc);
+                if (settings.useOpaqueHandle && settings.handleType == IpcHandleType::fdHandle) {
+                    this->driverHandle->unregisterIpcHandleWithServer(ipcHandleIterator->second->handle);
+                }
                 delete ipcHandleIterator->second;
                 this->driverHandle->getIPCHandleMap().erase(ipcHandleIterator->first);
             }
@@ -560,14 +565,12 @@ ze_result_t ContextImp::freeMem(const void *ptr, bool blocking) {
         ipcHandleIterator++;
     }
 
-    for (auto &pairDevice : this->devices) {
-        this->freePeerAllocations(ptr, blocking, Device::fromHandle(pairDevice.second));
-    }
-
     if (this->tryFreeViaPooling(ptr, allocation, usmPool, blocking)) {
         return ZE_RESULT_SUCCESS;
     }
 
+    this->freePeerAllocationsFromAll(ptr, blocking);
+
     this->driverHandle->svmAllocsManager->freeSVMAlloc(const_cast<void *>(ptr), blocking);
 
     return ZE_RESULT_SUCCESS;
@@ -590,14 +593,12 @@ ze_result_t ContextImp::freeMemExt(const ze_memory_free_ext_desc_t *pMemFreeDesc
             return ZE_RESULT_ERROR_INVALID_ARGUMENT;
         }
 
-        for (auto &pairDevice : this->devices) {
-            this->freePeerAllocations(ptr, false, Device::fromHandle(pairDevice.second));
-        }
-
         if (this->tryFreeViaPooling(ptr, allocation, usmPool, blocking)) {
             return ZE_RESULT_SUCCESS;
         }
 
+        this->freePeerAllocationsFromAll(ptr, blocking);
+
         this->driverHandle->svmAllocsManager->freeSVMAllocDefer(const_cast<void *>(ptr));
         return ZE_RESULT_SUCCESS;
     }
@@ -630,11 +631,10 @@ ze_result_t ContextImp::makeMemoryResident(ze_device_handle_t hDevice, void *ptr
         nullptr);
     if (allocation == nullptr) {
         NEO::SvmAllocationData *allocData = nullptr;
-        DriverHandleImp *driverHandleImp = static_cast<DriverHandleImp *>(this->driverHandle);
-        bool foundBuffer = driverHandleImp->findAllocationDataForRange(ptr, size, allocData);
+        bool foundBuffer = this->driverHandle->findAllocationDataForRange(ptr, size, allocData);
         if (foundBuffer) {
             uintptr_t alignedPtr = reinterpret_cast<uintptr_t>(ptr);
-            allocation = driverHandleImp->getPeerAllocation(device, allocData, ptr, &alignedPtr, nullptr);
+            allocation = this->driverHandle->getPeerAllocation(device, allocData, ptr, &alignedPtr, nullptr);
         }
         if (allocation == nullptr) {
             return ZE_RESULT_ERROR_INVALID_ARGUMENT;
@@ -651,9 +651,9 @@ ze_result_t ContextImp::makeMemoryResident(ze_device_handle_t hDevice, void *ptr
     if (ZE_RESULT_SUCCESS == res) {
         auto allocData = device->getDriverHandle()->getSvmAllocsManager()->getSVMAlloc(ptr);
         if (allocData && allocData->memoryType == InternalMemoryType::sharedUnifiedMemory) {
-            DriverHandleImp *driverHandleImp = static_cast<DriverHandleImp *>(device->getDriverHandle());
-            std::lock_guard<std::mutex> lock(driverHandleImp->sharedMakeResidentAllocationsLock);
-            driverHandleImp->sharedMakeResidentAllocations.insert({ptr, allocation});
+            auto driverHandle = device->getDriverHandle();
+            std::lock_guard<std::mutex> lock(driverHandle->sharedMakeResidentAllocationsLock);
+            driverHandle->sharedMakeResidentAllocations.insert({ptr, allocation});
         }
     }
 
@@ -677,9 +677,9 @@ ze_result_t ContextImp::evictMemory(ze_device_handle_t hDevice, void *ptr, size_
     }
 
     {
-        DriverHandleImp *driverHandleImp = static_cast<DriverHandleImp *>(device->getDriverHandle());
-        std::lock_guard<std::mutex> lock(driverHandleImp->sharedMakeResidentAllocationsLock);
-        driverHandleImp->sharedMakeResidentAllocations.erase(ptr);
+        auto driverHandle = device->getDriverHandle();
+        std::lock_guard<std::mutex> lock(driverHandle->sharedMakeResidentAllocationsLock);
+        driverHandle->sharedMakeResidentAllocations.erase(ptr);
     }
 
     NEO::MemoryOperationsHandler *memoryOperationsIface = neoDevice->getRootDeviceEnvironment().memoryOperationsInterface.get();
@@ -776,6 +776,9 @@ ze_result_t ContextImp::putIpcMemHandle(ze_ipc_mem_handle_t ipcHandle) {
         trackIPC->refcnt -= 1;
         if (trackIPC->refcnt == 0) {
             driverHandle->getMemoryManager()->closeInternalHandle(handle, trackIPC->handleId, trackIPC->alloc);
+            if (settings.useOpaqueHandle && settings.handleType == IpcHandleType::fdHandle) {
+                this->driverHandle->unregisterIpcHandleWithServer(handle);
+            }
             delete trackIPC;
             ipcMap.erase(handle);
         }
@@ -984,7 +987,7 @@ ze_result_t ContextImp::openCounterBasedIpcHandle(const IpcCounterBasedEventData
     return Event::openCounterBasedIpcHandle(ipcData, phEvent, driverHandle, this, this->numDevices, this->deviceHandles.data());
 }
 
-ze_result_t ContextImp::handleAllocationExtensions(NEO::GraphicsAllocation *alloc, ze_memory_type_t type, void *pNext, struct DriverHandleImp *driverHandle) {
+ze_result_t ContextImp::handleAllocationExtensions(NEO::GraphicsAllocation *alloc, ze_memory_type_t type, void *pNext, DriverHandle *driverHandle) {
     if (pNext != nullptr) {
         ze_base_properties_t *extendedProperties =
             reinterpret_cast<ze_base_properties_t *>(pNext);
@@ -1066,7 +1069,7 @@ ze_result_t ContextImp::getMemAllocProperties(const void *ptr,
         if (alloc->device == nullptr) {
             *phDevice = nullptr;
         } else {
-            auto device = static_cast<NEO::Device *>(alloc->device)->getSpecializedDevice<DeviceImp>();
+            auto device = static_cast<NEO::Device *>(alloc->device)->getSpecializedDevice<Device>();
             DEBUG_BREAK_IF(device == nullptr);
             *phDevice = device->toHandle();
         }
@@ -1114,13 +1117,12 @@ ze_result_t ContextImp::setAtomicAccessAttribute(ze_device_handle_t hDevice, con
         }
     }
 
-    DeviceImp *deviceImp = static_cast<DeviceImp *>((L0::Device::fromHandle(hDevice)));
     const bool isSharedSystemAlloc = ((allocData == nullptr) && sharedSystemAllocEnabled);
 
     auto attrEval = static_cast<uint32_t>(attr);
 
     ze_device_memory_access_properties_t memProp;
-    deviceImp->getMemoryAccessProperties(&memProp);
+    device->getMemoryAccessProperties(&memProp);
     NEO::AtomicAccessMode mode = NEO::AtomicAccessMode::invalid;
 
     if (attrEval & ZE_MEMORY_ATOMIC_ATTR_EXP_FLAG_DEVICE_ATOMICS) {
@@ -1175,12 +1177,14 @@ ze_result_t ContextImp::setAtomicAccessAttribute(ze_device_handle_t hDevice, con
 
     if (isSharedSystemAlloc) {
         auto unifiedMemoryManager = driverHandle->getSvmAllocsManager();
-        unifiedMemoryManager->sharedSystemAtomicAccess(*deviceImp->getNEODevice(), mode, ptr, size);
+        if (!unifiedMemoryManager->sharedSystemAtomicAccess(*device->getNEODevice(), mode, ptr, size)) {
+            return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
+        }
     } else {
         auto memoryManager = device->getDriverHandle()->getMemoryManager();
-        auto alloc = allocData->gpuAllocations.getGraphicsAllocation(deviceImp->getRootDeviceIndex());
-        memoryManager->setAtomicAccess(alloc, size, mode, deviceImp->getRootDeviceIndex());
-        deviceImp->atomicAccessAllocations[allocData] = attr;
+        auto alloc = allocData->gpuAllocations.getGraphicsAllocation(device->getRootDeviceIndex());
+        memoryManager->setAtomicAccess(alloc, size, mode, device->getRootDeviceIndex());
+        device->atomicAccessAllocations[allocData] = attr;
     }
 
     return ZE_RESULT_SUCCESS;
@@ -1197,12 +1201,10 @@ ze_result_t ContextImp::getAtomicAccessAttribute(ze_device_handle_t hDevice, con
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
     }
 
-    DeviceImp *deviceImp = static_cast<DeviceImp *>((L0::Device::fromHandle(hDevice)));
-
     if (isSharedSystemAlloc) {
 
         auto unifiedMemoryManager = driverHandle->getSvmAllocsManager();
-        auto mode = unifiedMemoryManager->getSharedSystemAtomicAccess(*deviceImp->getNEODevice(), ptr, size);
+        auto mode = unifiedMemoryManager->getSharedSystemAtomicAccess(*device->getNEODevice(), ptr, size);
         switch (mode) {
         case NEO::AtomicAccessMode::device:
             *pAttr = ZE_MEMORY_ATOMIC_ATTR_EXP_FLAG_DEVICE_ATOMICS;
@@ -1220,8 +1222,8 @@ ze_result_t ContextImp::getAtomicAccessAttribute(ze_device_handle_t hDevice, con
             return ZE_RESULT_ERROR_INVALID_ARGUMENT;
         }
     } else {
-        if (deviceImp->atomicAccessAllocations.find(allocData) != deviceImp->atomicAccessAllocations.end()) {
-            *pAttr = deviceImp->atomicAccessAllocations[allocData];
+        if (device->atomicAccessAllocations.find(allocData) != device->atomicAccessAllocations.end()) {
+            *pAttr = device->atomicAccessAllocations[allocData];
             return ZE_RESULT_SUCCESS;
         }
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
