@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,7 @@
 
 #pragma once
 
+#include "shared/source/debug_settings/debug_settings_manager.h"
 #include "shared/source/device/device.h"
 #include "shared/source/helpers/device_bitfield.h"
 #include "shared/source/helpers/non_copyable_or_moveable.h"
@@ -15,7 +16,7 @@
 #include "shared/source/utilities/stackvec.h"
 
 #include "level_zero/core/source/context/context.h"
-#include "level_zero/core/source/driver/driver_handle_imp.h"
+#include "level_zero/core/source/driver/driver_handle.h"
 
 #include <map>
 
@@ -28,11 +29,10 @@ struct VirtualMemoryReservation;
 
 namespace L0 {
 struct StructuresLookupTable;
-struct DriverHandleImp;
 struct Device;
 struct IpcCounterBasedEventData;
 class ContextExt;
-struct DriverHandle;
+class DriverHandle;
 
 ContextExt *createContextExt(DriverHandle *driverHandle);
 void destroyContextExt(ContextExt *ctxExt);
@@ -183,10 +183,11 @@ struct ContextImp : Context, NEO::NonCopyableAndNonMovableClass {
         return devices;
     }
 
+    MOCKABLE_VIRTUAL void freePeerAllocationsFromAll(const void *ptr, bool blocking);
     void freePeerAllocations(const void *ptr, bool blocking, Device *device);
 
     ze_result_t handleAllocationExtensions(NEO::GraphicsAllocation *alloc, ze_memory_type_t type,
-                                           void *pNext, struct DriverHandleImp *driverHandle);
+                                           void *pNext, DriverHandle *driverHandle);
 
     RootDeviceIndicesContainer rootDeviceIndices;
     std::map<uint32_t, NEO::DeviceBitfield> deviceBitfields;
@@ -271,6 +272,20 @@ struct ContextImp : Context, NEO::NonCopyableAndNonMovableClass {
                 handleTracking->opaqueData = ipcData;
             }
             this->driverHandle->getIPCHandleMap().insert(std::pair<uint64_t, IpcHandleTracking *>(handle, handleTracking));
+
+            if constexpr (std::is_same_v<IpcDataT, IpcOpaqueMemoryData>) {
+                if (handleType == IpcHandleType::fdHandle && NEO::debugManager.flags.EnableIpcSocketFallback.get()) {
+                    if (this->driverHandle->initializeIpcSocketServer()) {
+                        if (!this->driverHandle->registerIpcHandleWithServer(handle, static_cast<int>(handle))) {
+                            PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr,
+                                         "Failed to register handle %lu with IPC socket server\n", handle);
+                        }
+                    } else {
+                        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr,
+                                     "Failed to initialize IPC socket server for handle %lu\n", handle);
+                    }
+                }
+            }
         }
     }
     bool isAllocationSuitableForCompression(const StructuresLookupTable &structuresLookupTable, Device &device, size_t allocSize);
@@ -283,7 +298,7 @@ struct ContextImp : Context, NEO::NonCopyableAndNonMovableClass {
 
     std::map<uint32_t, ze_device_handle_t> devices;
     std::vector<ze_device_handle_t> deviceHandles;
-    DriverHandleImp *driverHandle = nullptr;
+    DriverHandle *driverHandle = nullptr;
     uint32_t numDevices = 0;
     ContextExt *contextExt = nullptr;
 };
