@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2025 Intel Corporation
+ * Copyright (C) 2022-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,7 +16,7 @@
 #include "shared/source/utilities/directory.h"
 
 #include "level_zero/core/source/context/context_imp.h"
-#include "level_zero/core/source/device/device_imp.h"
+#include "level_zero/core/source/device/device.h"
 
 #include <fcntl.h>
 
@@ -26,7 +26,7 @@ const std::string iafDirectoryLegacy = "iaf.";
 const std::string iafDirectory = "i915.iaf.";
 const std::string fabricIdFile = "/iaf_fabric_id";
 
-ze_result_t queryFabricStatsDrm(DeviceImp *pSourceDevice, DeviceImp *pPeerDevice, uint32_t &latency, uint32_t &bandwidth) {
+ze_result_t queryFabricStatsDrm(Device *pSourceDevice, Device *pPeerDevice, uint32_t &latency, uint32_t &bandwidth) {
     auto &osPeerInterface = pPeerDevice->getNEODevice()->getRootDeviceEnvironment().osInterface;
     auto pPeerDrm = osPeerInterface->getDriverModel()->as<NEO::Drm>();
     auto peerDevicePath = pPeerDrm->getSysFsPciPath();
@@ -71,17 +71,17 @@ ze_result_t queryFabricStatsDrm(DeviceImp *pSourceDevice, DeviceImp *pPeerDevice
 }
 
 bool queryPeerAccessDrm(NEO::Device &device, NEO::Device &peerDevice, void **handlePtr, uint64_t *handle) {
-    auto deviceImp = device.getSpecializedDevice<DeviceImp>();
-    auto peerImp = peerDevice.getSpecializedDevice<DeviceImp>();
+    auto l0Device = device.getSpecializedDevice<Device>();
+    auto l0PeerDevice = peerDevice.getSpecializedDevice<Device>();
 
     uint32_t latency = std::numeric_limits<uint32_t>::max();
     uint32_t bandwidth = 0;
-    ze_result_t fabricResult = queryFabricStatsDrm(deviceImp, peerImp, latency, bandwidth);
+    ze_result_t fabricResult = queryFabricStatsDrm(l0Device, l0PeerDevice, latency, bandwidth);
     if (fabricResult == ZE_RESULT_SUCCESS) {
         return true;
     }
 
-    auto driverHandle = static_cast<DriverHandleImp *>(deviceImp->getDriverHandle());
+    auto driverHandle = l0Device->getDriverHandle();
     auto context = static_cast<ContextImp *>(driverHandle->getDefaultContext());
 
     if (*handlePtr == nullptr) {
@@ -93,7 +93,7 @@ bool queryPeerAccessDrm(NEO::Device &device, NEO::Device &peerDevice, void **han
         deviceAllocDesc.stype = ZE_STRUCTURE_TYPE_DEVICE_MEM_ALLOC_DESC;
         deviceAllocDesc.pNext = &exportDesc;
 
-        ze_result_t allocResult = context->allocDeviceMem(deviceImp->toHandle(), &deviceAllocDesc, 1u, 1u, handlePtr);
+        ze_result_t allocResult = context->allocDeviceMem(l0Device->toHandle(), &deviceAllocDesc, 1u, 1u, handlePtr);
         if (allocResult != ZE_RESULT_SUCCESS) {
             return false;
         }
