@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024-2025 Intel Corporation
+ * Copyright (C) 2024-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,11 +8,13 @@
 #include "level_zero/core/source/driver/extension_function_address.h"
 
 #include "level_zero/api/extensions/public/ze_exp_ext.h"
+#include "level_zero/api/internal/l0_internal.h"
 #include "level_zero/driver_experimental/mcl_ext/zex_mutable_cmdlist_ext.h"
 #include "level_zero/driver_experimental/zex_api.h"
 #include "level_zero/driver_experimental/zex_cmdlist.h"
 #include "level_zero/driver_experimental/zex_context.h"
 #include "level_zero/ze_intel_gpu.h"
+#include "level_zero/zes_intel_gpu_sysman.h"
 #include "level_zero/zet_intel_gpu_metric.h"
 
 #include <cstring>
@@ -27,17 +29,25 @@ void *ExtensionFunctionAddressHelper::getExtensionFunctionAddress(const std::str
         }                                 \
     }
 
+#define RETURN_L0_FUNC_PTR_IF_EXIST(name)     \
+    {                                         \
+        if (functionName == #name) {          \
+            void *ret = ((void *)(L0::name)); \
+            return ret;                       \
+        }                                     \
+    }
+
     RETURN_FUNC_PTR_IF_EXIST(zexDriverImportExternalPointer);
     RETURN_FUNC_PTR_IF_EXIST(zexDriverReleaseImportedPointer);
     RETURN_FUNC_PTR_IF_EXIST(zexDriverGetHostPointerBaseAddress);
 
     RETURN_FUNC_PTR_IF_EXIST(zeDeviceGetPriorityLevels);
 
-    RETURN_FUNC_PTR_IF_EXIST(zexKernelGetBaseAddress);
-    RETURN_FUNC_PTR_IF_EXIST(zexKernelGetArgumentSize);
-    RETURN_FUNC_PTR_IF_EXIST(zexKernelGetArgumentType);
+    RETURN_L0_FUNC_PTR_IF_EXIST(zexKernelGetBaseAddress);
+    RETURN_L0_FUNC_PTR_IF_EXIST(zexKernelGetArgumentSize);
+    RETURN_L0_FUNC_PTR_IF_EXIST(zexKernelGetArgumentType);
 
-    RETURN_FUNC_PTR_IF_EXIST(zeIntelKernelGetBinaryExp);
+    RETURN_L0_FUNC_PTR_IF_EXIST(zeIntelKernelGetBinaryExp);
 
     RETURN_FUNC_PTR_IF_EXIST(zexMemGetIpcHandles);
     RETURN_FUNC_PTR_IF_EXIST(zexMemOpenIpcHandles);
@@ -132,7 +142,13 @@ void *ExtensionFunctionAddressHelper::getExtensionFunctionAddress(const std::str
     RETURN_FUNC_PTR_IF_EXIST(zeGraphIsEmptyExp);
     RETURN_FUNC_PTR_IF_EXIST(zeGraphDumpContentsExp);
 
+    // Sysman
+    RETURN_FUNC_PTR_IF_EXIST(zesIntelRasGetSupportedCategoriesExp);
+    RETURN_FUNC_PTR_IF_EXIST(zesIntelRasGetConfigExp);
+    RETURN_FUNC_PTR_IF_EXIST(zesIntelRasSetConfigExp);
+
 #undef RETURN_FUNC_PTR_IF_EXIST
+#undef RETURN_L0_FUNC_PTR_IF_EXIST
 
     return ExtensionFunctionAddressHelper::getAdditionalExtensionFunctionAddress(functionName);
 }
