@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -68,7 +68,7 @@ ze_result_t CommandListCoreFamily<gfxCoreFamily>::appendLaunchKernelWithParams(K
                                                                                CmdListKernelLaunchParams &launchParams) {
     UNRECOVERABLE_IF(kernel == nullptr);
     UNRECOVERABLE_IF(launchParams.skipInOrderNonWalkerSignaling);
-    const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+    const auto driverHandle = device->getDriverHandle();
     const auto &kernelDescriptor = kernel->getKernelDescriptor();
     if (kernelDescriptor.kernelAttributes.flags.isInvalid) {
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
@@ -202,8 +202,6 @@ ze_result_t CommandListCoreFamily<gfxCoreFamily>::appendLaunchKernelWithParams(K
 
     updateStreamProperties(*kernel, launchParams.isCooperative, threadGroupDimensions, launchParams.isIndirect);
 
-    auto maxWgCountPerTile = kernel->getMaxWgCountPerTile(this->engineGroupType);
-
     NEO::EncodeDispatchKernelArgs dispatchKernelArgs{
         .device = neoDevice,
         .dispatchInterface = kernel,
@@ -226,22 +224,21 @@ ze_result_t CommandListCoreFamily<gfxCoreFamily>::appendLaunchKernelWithParams(K
             .inOrderIncrementValue = 0,
             .device = neoDevice,
             .inOrderExecInfo = nullptr,
-            .isCounterBasedEvent = false,
-            .isTimestampEvent = false,
-            .isHostScopeSignalEvent = false,
-            .isUsingSystemAllocation = false,
+            .tsNode = nullptr,
             .dcFlushEnable = this->dcFlushSupport,
             .interruptEvent = false,
+            .isCounterBasedEvent = false,
             .isFlushL3ForExternalAllocationRequired = false,
             .isFlushL3ForHostUsmRequired = false,
+            .isHostScopeSignalEvent = false,
+            .isTimestampEvent = false,
+            .isUsingSystemAllocation = false,
         },
         .preemptionMode = commandListPreemptionMode,
         .requiredPartitionDim = launchParams.requiredPartitionDim,
         .requiredDispatchWalkOrder = launchParams.requiredDispatchWalkOrder,
-        .localRegionSize = launchParams.localRegionSize,
         .partitionCount = 0,
         .reserveExtraPayloadSpace = launchParams.reserveExtraPayloadSpace,
-        .maxWgCountPerTile = maxWgCountPerTile,
         .defaultPipelinedThreadArbitrationPolicy = NEO::ThreadArbitrationPolicy::NotPresent,
         .isIndirect = launchParams.isIndirect,
         .isPredicate = launchParams.isPredicate,
