@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -38,8 +38,7 @@
 #include "shared/source/utilities/shared_pool_allocation.h"
 
 #include "level_zero/core/source/device/device.h"
-#include "level_zero/core/source/device/device_imp.h"
-#include "level_zero/core/source/driver/driver_handle_imp.h"
+#include "level_zero/core/source/driver/driver_handle.h"
 #include "level_zero/core/source/image/image.h"
 #include "level_zero/core/source/image/image_format_desc_helper.h"
 #include "level_zero/core/source/kernel/kernel_shared_state.h"
@@ -78,8 +77,7 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
     this->kernelInfo = kernelInfo;
     this->kernelDescriptor = &kernelInfo->kernelDescriptor;
 
-    DeviceImp *deviceImp = static_cast<DeviceImp *>(device);
-    auto neoDevice = deviceImp->getActiveDevice();
+    auto neoDevice = device->getActiveDevice();
 
     if (neoDevice->getDebugger() && kernelInfo->kernelDescriptor.external.debugData.get()) {
         createRelocatedDebugData(globalConstBuffer, globalVarBuffer);
@@ -111,7 +109,7 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
         memcpy_s(surfaceStateHeapTemplate.get(), surfaceStateHeapSize,
                  kernelInfo->heapInfo.pSsh, surfaceStateHeapSize);
     } else if (NEO::KernelDescriptor::isBindlessAddressingKernel(kernelInfo->kernelDescriptor)) {
-        auto &gfxCoreHelper = deviceImp->getNEODevice()->getGfxCoreHelper();
+        auto &gfxCoreHelper = device->getNEODevice()->getGfxCoreHelper();
         auto surfaceStateSize = static_cast<uint32_t>(gfxCoreHelper.getRenderSurfaceStateSize());
 
         this->surfaceStateHeapSize = (kernelInfo->kernelDescriptor.kernelAttributes.numArgsStateful +
@@ -138,7 +136,7 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
         patchWithImplicitSurface(crossThreadDataArrayRef, surfaceStateHeapArrayRef,
                                  static_cast<uintptr_t>(globalConstBuffer->getGpuAddressToPatch()),
                                  *globalConstBuffer->getGraphicsAllocation(), globalConstBuffer->getGpuAddress(), globalConstBuffer->getSize(),
-                                 kernelDescriptor->payloadMappings.implicitArgs.globalConstantsSurfaceAddress, *neoDevice, deviceImp->isImplicitScalingCapable());
+                                 kernelDescriptor->payloadMappings.implicitArgs.globalConstantsSurfaceAddress, *neoDevice, device->isImplicitScalingCapable());
         this->residencyContainer.push_back(globalConstBuffer->getGraphicsAllocation());
     } else if (nullptr != globalConstBuffer) {
         this->residencyContainer.push_back(globalConstBuffer->getGraphicsAllocation());
@@ -153,7 +151,7 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
 
         patchImplicitArgBindlessOffsetAndSetSurfaceState(crossThreadDataArrayRef, surfaceStateHeapArrayRef,
                                                          globalConstBuffer->getGraphicsAllocation(), kernelDescriptor->payloadMappings.implicitArgs.globalConstantsSurfaceAddress,
-                                                         *neoDevice, deviceImp->isImplicitScalingCapable(), ssInHeap, kernelInfo->kernelDescriptor);
+                                                         *neoDevice, device->isImplicitScalingCapable(), ssInHeap, kernelInfo->kernelDescriptor);
     }
 
     if (NEO::isValidOffset(kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress.stateless)) {
@@ -162,7 +160,7 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
         patchWithImplicitSurface(crossThreadDataArrayRef, surfaceStateHeapArrayRef,
                                  static_cast<uintptr_t>(globalVarBuffer->getGpuAddressToPatch()),
                                  *globalVarBuffer->getGraphicsAllocation(), globalVarBuffer->getGpuAddress(), globalVarBuffer->getSize(),
-                                 kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress, *neoDevice, deviceImp->isImplicitScalingCapable());
+                                 kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress, *neoDevice, device->isImplicitScalingCapable());
         this->residencyContainer.push_back(globalVarBuffer->getGraphicsAllocation());
     } else if (nullptr != globalVarBuffer) {
         this->residencyContainer.push_back(globalVarBuffer->getGraphicsAllocation());
@@ -177,7 +175,7 @@ ze_result_t KernelImmutableData::initialize(NEO::KernelInfo *kernelInfo, Device
 
         patchImplicitArgBindlessOffsetAndSetSurfaceState(crossThreadDataArrayRef, surfaceStateHeapArrayRef,
                                                          globalVarBuffer->getGraphicsAllocation(), kernelDescriptor->payloadMappings.implicitArgs.globalVariablesSurfaceAddress,
-                                                         *neoDevice, deviceImp->isImplicitScalingCapable(), ssInHeap, kernelInfo->kernelDescriptor);
+                                                         *neoDevice, device->isImplicitScalingCapable(), ssInHeap, kernelInfo->kernelDescriptor);
     }
 
     return ZE_RESULT_SUCCESS;
@@ -541,8 +539,6 @@ ze_result_t KernelImp::setGroupSize(uint32_t groupSizeX, uint32_t groupSizeY,
         privateState.reservePerThreadDataForWholeThreadGroup(perThreadDataSizeForWholeThreadGroupNeeded);
 
         if (numChannels > 0) {
-            UNRECOVERABLE_IF(3 != numChannels);
-
             std::array<uint8_t, 3> walkOrder{0, 1, 2};
             if (kernelDescriptor.kernelAttributes.flags.requiresWorkgroupWalkOrder) {
                 walkOrder = {
@@ -558,7 +554,7 @@ ze_result_t KernelImp::setGroupSize(uint32_t groupSizeX, uint32_t groupSizeY,
                                          static_cast<uint16_t>(groupSizeY),
                                          static_cast<uint16_t>(groupSizeZ)}},
                 walkOrder,
-                false, grfSize, grfCount, rootDeviceEnvironment);
+                false, grfSize, grfCount, rootDeviceEnvironment, numChannels);
         }
 
         this->privateState.perThreadDataSize = this->privateState.perThreadDataSizeForWholeThreadGroup / this->privateState.numThreadsPerThreadGroup;
@@ -567,15 +563,6 @@ ze_result_t KernelImp::setGroupSize(uint32_t groupSizeX, uint32_t groupSizeY,
         this->privateState.perThreadDataSize = 0;
     }
 
-    if (this->sharedState->heaplessEnabled && this->sharedState->localDispatchSupport) {
-        this->sharedState->maxWgCountPerTileCcs = suggestMaxCooperativeGroupCount(NEO::EngineGroupType::compute, true);
-        if (this->sharedState->rcsAvailable) {
-            this->sharedState->maxWgCountPerTileRcs = suggestMaxCooperativeGroupCount(NEO::EngineGroupType::renderCompute, true);
-        }
-        if (this->sharedState->cooperativeSupport) {
-            this->sharedState->maxWgCountPerTileCooperative = suggestMaxCooperativeGroupCount(NEO::EngineGroupType::cooperativeCompute, true);
-        }
-    }
     return ZE_RESULT_SUCCESS;
 }
 
@@ -611,8 +598,8 @@ ze_result_t KernelImp::suggestGroupSize(uint32_t globalSizeX, uint32_t globalSiz
         uint32_t localMemSize = (uint32_t)deviceInfo.localMemSize;
 
         if (this->getSlmTotalSize() > 0 && localMemSize < this->getSlmTotalSize()) {
-            const auto device = static_cast<DeviceImp *>(module->getDevice());
-            const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+            const auto device = module->getDevice();
+            const auto driverHandle = device->getDriverHandle();
 
             CREATE_DEBUG_STRING(str, "Size of SLM (%u) larger than available (%u)\n", this->getSlmTotalSize(), localMemSize);
             driverHandle->setErrorDescription(std::string(str.get()));
@@ -824,8 +811,8 @@ ze_result_t KernelImp::setArgUnknown(uint32_t argIndex, size_t argSize, const vo
 }
 
 ze_result_t KernelImp::setArgBuffer(uint32_t argIndex, size_t argSize, const void *argVal) {
-    const auto device = static_cast<DeviceImp *>(this->module->getDevice());
-    const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+    const auto device = this->module->getDevice();
+    const auto driverHandle = device->getDriverHandle();
     const auto svmAllocsManager = driverHandle->getSvmAllocsManager();
     const auto allocationsCounter = svmAllocsManager->allocationsCounter.load();
     const auto &argInfo = this->privateState.kernelArgInfos[argIndex];
@@ -904,13 +891,24 @@ ze_result_t KernelImp::setArgBuffer(uint32_t argIndex, size_t argSize, const voi
     }
 
     NEO::SvmAllocationData *peerAllocData = nullptr;
-    if (allocData && driverHandle->isRemoteResourceNeeded(requestedAddress, alloc, allocData, device)) {
+    if (allocData && driverHandle->isRemoteResourceNeeded(alloc, allocData, device)) {
 
         uint64_t pbase = allocData->gpuAllocations.getDefaultGraphicsAllocation()->getGpuAddress();
         uint64_t offset = (uint64_t)requestedAddress - pbase;
         alloc = driverHandle->getPeerAllocation(device, allocData, reinterpret_cast<void *>(pbase), &gpuAddress, &peerAllocData);
         if (alloc == nullptr) {
-            return ZE_RESULT_ERROR_INVALID_ARGUMENT;
+            if (NEO::debugManager.flags.DisableSystemPointerKernelArgument.get() != 1) {
+                privateState.argumentsResidencyContainer[argIndex] = nullptr;
+                const auto &argAsPtr = getImmutableData()->getDescriptor().payloadMappings.explicitArgs[argIndex].as<NEO::ArgDescPointer>();
+                auto patchLocation = ptrOffset(getCrossThreadData(), argAsPtr.stateless);
+                NEO::patchNonPointer<int64_t, int64_t>(getCrossThreadDataSpan(), argAsPtr.bufferSize, 0);
+                patchWithRequiredSize(const_cast<uint8_t *>(patchLocation), argAsPtr.pointerSize, reinterpret_cast<uintptr_t>(requestedAddress));
+                const uint32_t allocId = allocData->getAllocId();
+                privateState.kernelArgInfos[argIndex] = KernelArgInfo{requestedAddress, allocId, allocationsCounter, false};
+                return ZE_RESULT_SUCCESS;
+            } else {
+                return ZE_RESULT_ERROR_INVALID_ARGUMENT;
+            }
         }
         gpuAddress += offset;
     }
@@ -1214,8 +1212,6 @@ ze_result_t KernelImp::initialize(const ze_kernel_desc_t *desc) {
     bool platformImplicitScaling = gfxHelper.platformSupportsImplicitScaling(rootDeviceEnvironment);
     sharedState.implicitScalingEnabled = NEO::ImplicitScalingHelper::isImplicitScalingEnabled(deviceBitfield, platformImplicitScaling);
 
-    sharedState.rcsAvailable = gfxHelper.isRcsAvailable(hwInfo);
-    sharedState.cooperativeSupport = productHelper.isCooperativeEngineSupported(hwInfo);
     sharedState.walkerInlineDataSize = gfxHelper.getDefaultWalkerInlineDataSize();
     sharedState.surfaceStateAlignmentMask = gfxHelper.getSurfaceBaseAddressAlignmentMask();
     sharedState.surfaceStateAlignment = gfxHelper.getSurfaceBaseAddressAlignment();
@@ -1395,7 +1391,7 @@ ze_result_t KernelImp::destroy() {
 std::unique_ptr<KernelImp> KernelImp::makeDependentClone() {
     DEBUG_BREAK_IF(nullptr == this->ownedSharedState.get());
 
-    auto *device{static_cast<DeviceImp *>(this->module->getDevice())};
+    auto *device{this->module->getDevice()};
     const auto productFamily = device->getNEODevice()->getHardwareInfo().platform.eProductFamily;
     KernelAllocatorFn allocator = kernelFactory[productFamily];
     auto clone = static_cast<KernelImp *>(allocator(nullptr));
@@ -1419,7 +1415,7 @@ void KernelImp::createPrintfBuffer() {
         if (privateState.pImplicitArgs) {
             privateState.pImplicitArgs->setPrintfBuffer(sharedState.printfBuffer->getGpuAddress());
         }
-        sharedState.devicePrintfKernelMutex = &(static_cast<DeviceImp *>(this->module->getDevice())->printfKernelMutex);
+        sharedState.devicePrintfKernelMutex = &(this->module->getDevice()->printfKernelMutex);
     }
 }
 
@@ -1431,10 +1427,6 @@ bool KernelImp::usesSyncBuffer() {
     return this->getImmutableData()->getDescriptor().kernelAttributes.flags.usesSyncBuffer;
 }
 
-bool KernelImp::usesRegionGroupBarrier() const {
-    return this->getImmutableData()->getDescriptor().kernelAttributes.flags.usesRegionGroupBarrier;
-}
-
 void KernelImp::patchSyncBuffer(NEO::GraphicsAllocation *gfxAllocation, size_t bufferOffset) {
     if (privateState.syncBufferIndex == std::numeric_limits<size_t>::max()) {
         privateState.syncBufferIndex = this->privateState.internalResidencyContainer.size();
@@ -1450,19 +1442,6 @@ void KernelImp::patchSyncBuffer(NEO::GraphicsAllocation *gfxAllocation, size_t b
     }
 }
 
-void KernelImp::patchRegionGroupBarrier(NEO::GraphicsAllocation *gfxAllocation, size_t bufferOffset) {
-    if (privateState.regionGroupBarrierIndex == std::numeric_limits<size_t>::max()) {
-        privateState.regionGroupBarrierIndex = this->privateState.internalResidencyContainer.size();
-        this->privateState.internalResidencyContainer.push_back(gfxAllocation);
-    } else {
-        this->privateState.internalResidencyContainer[privateState.regionGroupBarrierIndex] = gfxAllocation;
-    }
-
-    NEO::patchPointer(getCrossThreadDataSpan(),
-                      this->getImmutableData()->getDescriptor().payloadMappings.implicitArgs.regionGroupBarrierBuffer,
-                      static_cast<uintptr_t>(ptrOffset(gfxAllocation->getGpuAddressToPatch(), bufferOffset)));
-}
-
 uint32_t KernelImp::getSurfaceStateHeapDataSize() const {
     if (NEO::KernelDescriptor::isBindlessAddressingKernel(getImmutableData()->getDescriptor())) {
         if (std::none_of(privateState.usingSurfaceStateHeap.cbegin(), privateState.usingSurfaceStateHeap.cend(), [](bool i) { return i; })) {
