@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -10,7 +10,6 @@
 #include "shared/source/command_stream/command_stream_receiver.h"
 #include "shared/source/compiler_interface/compiler_interface.h"
 #include "shared/source/compiler_interface/compiler_options.h"
-#include "shared/source/compiler_interface/compiler_options_extra.h"
 #include "shared/source/compiler_interface/compiler_warnings/compiler_warnings.h"
 #include "shared/source/compiler_interface/external_functions.h"
 #include "shared/source/compiler_interface/linker.h"
@@ -44,11 +43,11 @@
 #include "shared/source/program/kernel_info.h"
 #include "shared/source/program/metadata_generation.h"
 #include "shared/source/program/program_initialization.h"
+#include "shared/source/utilities/stackvec.h"
 
 #include "level_zero/core/source/device/device.h"
-#include "level_zero/core/source/device/device_imp.h"
 #include "level_zero/core/source/driver/driver_handle.h"
-#include "level_zero/core/source/driver/driver_handle_imp.h"
+#include "level_zero/core/source/helpers/pnext.h"
 #include "level_zero/core/source/kernel/kernel.h"
 #include "level_zero/core/source/module/module_build_log.h"
 
@@ -226,7 +225,7 @@ bool ModuleTranslationUnit::processSpecConstantInfo(NEO::CompilerInterface *comp
 
 ze_result_t ModuleTranslationUnit::compileGenBinary(NEO::TranslationInput &inputArgs, bool staticLink) {
     auto compilerInterface = device->getNEODevice()->getCompilerInterface();
-    const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+    const auto driverHandle = device->getDriverHandle();
     if (!compilerInterface) {
         driverHandle->clearErrorDescription();
         return ZE_RESULT_ERROR_DEPENDENCY_UNAVAILABLE;
@@ -264,7 +263,7 @@ ze_result_t ModuleTranslationUnit::compileGenBinary(NEO::TranslationInput &input
 ze_result_t ModuleTranslationUnit::staticLinkSpirV(std::vector<const char *> inputSpirVs, std::vector<uint32_t> inputModuleSizes, const char *buildOptions, const char *internalBuildOptions,
                                                    std::vector<const ze_module_constants_t *> specConstants) {
     auto compilerInterface = device->getNEODevice()->getCompilerInterface();
-    const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+    const auto driverHandle = device->getDriverHandle();
     if (!compilerInterface) {
         driverHandle->clearErrorDescription();
         return ZE_RESULT_ERROR_DEPENDENCY_UNAVAILABLE;
@@ -293,7 +292,7 @@ ze_result_t ModuleTranslationUnit::staticLinkSpirV(std::vector<const char *> inp
 ze_result_t ModuleTranslationUnit::buildFromSource(ze_module_format_t inputFormat, const char *input, uint32_t inputSize, const char *buildOptions, const char *internalBuildOptions) {
     const auto &neoDevice = device->getNEODevice();
     auto compilerInterface = neoDevice->getCompilerInterface();
-    const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+    const auto driverHandle = device->getDriverHandle();
     if (!compilerInterface) {
         driverHandle->clearErrorDescription();
         return ZE_RESULT_ERROR_DEPENDENCY_UNAVAILABLE;
@@ -314,7 +313,7 @@ ze_result_t ModuleTranslationUnit::buildFromIntermediate(IGC::CodeType::CodeType
                                                          const ze_module_constants_t *pConstants) {
     const auto &neoDevice = device->getNEODevice();
     auto compilerInterface = neoDevice->getCompilerInterface();
-    const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+    const auto driverHandle = device->getDriverHandle();
     if (!compilerInterface) {
         driverHandle->clearErrorDescription();
         return ZE_RESULT_ERROR_DEPENDENCY_UNAVAILABLE;
@@ -346,7 +345,7 @@ ze_result_t ModuleTranslationUnit::createFromNativeBinary(const char *input, siz
     ArrayRef<const uint8_t> archive(reinterpret_cast<const uint8_t *>(input), inputSize);
     auto singleDeviceBinary = unpackSingleDeviceBinary(archive, NEO::ConstStringRef(productAbbreviation, strlen(productAbbreviation)), targetDevice,
                                                        decodeErrors, decodeWarnings);
-    const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+    const auto driverHandle = device->getDriverHandle();
     if (decodeWarnings.empty() == false) {
         PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "%s\n", decodeWarnings.c_str());
     }
@@ -405,7 +404,7 @@ ze_result_t ModuleTranslationUnit::createFromNativeBinary(const char *input, siz
 }
 
 ze_result_t ModuleTranslationUnit::processUnpackedBinary() {
-    const auto driverHandle = static_cast<DriverHandleImp *>(device->getDriverHandle());
+    const auto driverHandle = device->getDriverHandle();
     if (0 == unpackedDeviceBinarySize) {
         driverHandle->clearErrorDescription();
         return ZE_RESULT_ERROR_MODULE_BUILD_FAILURE;
@@ -742,18 +741,17 @@ std::pair<const void *, size_t> ModuleImp::getKernelHeapPointerAndSize(const std
 inline ze_result_t ModuleImp::initializeTranslationUnit(const ze_module_desc_t *desc, NEO::Device *neoDevice) {
     std::string buildOptions;
     std::string internalBuildOptions;
+    auto extensions = L0::PNextRange(desc->pNext);
+    auto moduleProgExt = extensions.get<ze_module_program_exp_desc_t>(ZE_STRUCTURE_TYPE_MODULE_PROGRAM_EXP_DESC);
 
-    if (desc->pNext) {
-        const ze_base_desc_t *expDesc = reinterpret_cast<const ze_base_desc_t *>(desc->pNext);
-        if (expDesc->stype != ZE_STRUCTURE_TYPE_MODULE_PROGRAM_EXP_DESC) {
-            return ZE_RESULT_ERROR_INVALID_ARGUMENT;
-        }
-        if (desc->format != ZE_MODULE_FORMAT_IL_SPIRV) {
+    for (auto &ext : extensions) {
+        if (ext.stype != ZE_STRUCTURE_TYPE_MODULE_PROGRAM_EXP_DESC) {
             return ZE_RESULT_ERROR_INVALID_ARGUMENT;
         }
+    }
+
+    if (moduleProgExt && (desc->format == ZE_MODULE_FORMAT_IL_SPIRV)) {
         this->builtFromSpirv = true;
-        const ze_module_program_exp_desc_t *programExpDesc =
-            reinterpret_cast<const ze_module_program_exp_desc_t *>(expDesc);
         std::vector<const char *> inputSpirVs;
         std::vector<uint32_t> inputModuleSizes;
         std::vector<const ze_module_constants_t *> specConstants;
@@ -761,23 +759,23 @@ inline ze_result_t ModuleImp::initializeTranslationUnit(const ze_module_desc_t *
 
         this->createBuildOptions(nullptr, buildOptions, internalBuildOptions);
 
-        inputSpirVs.reserve(programExpDesc->count);
-        inputModuleSizes.reserve(programExpDesc->count);
-        for (uint32_t i = 0; i < static_cast<uint32_t>(programExpDesc->count); i++) {
+        inputSpirVs.reserve(moduleProgExt->count);
+        inputModuleSizes.reserve(moduleProgExt->count);
+        for (uint32_t i = 0; i < static_cast<uint32_t>(moduleProgExt->count); i++) {
             std::string tmpBuildOptions;
             std::string tmpInternalBuildOptions;
-            inputSpirVs.push_back(reinterpret_cast<const char *>(programExpDesc->pInputModules[i]));
-            auto inputSizesInfo = const_cast<size_t *>(programExpDesc->inputSizes);
+            inputSpirVs.push_back(reinterpret_cast<const char *>(moduleProgExt->pInputModules[i]));
+            auto inputSizesInfo = const_cast<size_t *>(moduleProgExt->inputSizes);
             uint32_t inputSize = static_cast<uint32_t>(inputSizesInfo[i]);
             inputModuleSizes.push_back(inputSize);
-            if (programExpDesc->pConstants) {
-                specConstants.push_back(programExpDesc->pConstants[i]);
+            if (moduleProgExt->pConstants) {
+                specConstants.push_back(moduleProgExt->pConstants[i]);
                 if (i == 0) {
                     firstSpecConstants = specConstants[0];
                 }
             }
-            if (programExpDesc->pBuildFlags) {
-                this->createBuildOptions(programExpDesc->pBuildFlags[i], tmpBuildOptions, tmpInternalBuildOptions);
+            if (moduleProgExt->pBuildFlags) {
+                this->createBuildOptions(moduleProgExt->pBuildFlags[i], tmpBuildOptions, tmpInternalBuildOptions);
                 buildOptions = buildOptions + tmpBuildOptions;
                 internalBuildOptions = internalBuildOptions + tmpInternalBuildOptions;
             }
@@ -792,7 +790,7 @@ inline ze_result_t ModuleImp::initializeTranslationUnit(const ze_module_desc_t *
                                                           std::move(specConstants));
         } else {
             this->precompiled = false;
-            return this->translationUnit->buildFromSpirV(reinterpret_cast<const char *>(programExpDesc->pInputModules[0]),
+            return this->translationUnit->buildFromSpirV(reinterpret_cast<const char *>(moduleProgExt->pInputModules[0]),
                                                          inputModuleSizes[0],
                                                          buildOptions.c_str(),
                                                          internalBuildOptions.c_str(),
@@ -1072,7 +1070,7 @@ void ModuleImp::updateBuildLog(NEO::Device *neoDevice) {
 ze_result_t ModuleImp::createKernel(const ze_kernel_desc_t *desc,
                                     ze_kernel_handle_t *kernelHandle) {
     ze_result_t res;
-    const auto driverHandle = static_cast<DriverHandleImp *>((this->getDevice())->getDriverHandle());
+    const auto driverHandle = this->getDevice()->getDriverHandle();
     if (!isFullyLinked) {
         driverHandle->clearErrorDescription();
         return ZE_RESULT_ERROR_INVALID_MODULE_UNLINKED;
@@ -1092,7 +1090,7 @@ ze_result_t ModuleImp::createKernel(const ze_kernel_desc_t *desc,
 }
 
 std::weak_ptr<Kernel> ModuleImp::getPrintfKernelWeakPtr(ze_kernel_handle_t kernelHandle) const {
-    std::lock_guard<std::mutex> lock(static_cast<DeviceImp *>(device)->printfKernelMutex);
+    std::lock_guard<std::mutex> lock(device->printfKernelMutex);
     Kernel *kernel = Kernel::fromHandle(kernelHandle);
     auto it = std::find_if(this->printfKernelContainer.begin(), this->printfKernelContainer.end(), [&kernel](const auto &kernelSharedPtr) { return kernelSharedPtr.get() == kernel; });
     if (it == this->printfKernelContainer.end()) {
@@ -1103,7 +1101,7 @@ std::weak_ptr<Kernel> ModuleImp::getPrintfKernelWeakPtr(ze_kernel_handle_t kerne
 }
 
 ze_result_t ModuleImp::destroyPrintfKernel(ze_kernel_handle_t kernelHandle) {
-    std::lock_guard<std::mutex> lock(static_cast<DeviceImp *>(device)->printfKernelMutex);
+    std::lock_guard<std::mutex> lock(device->printfKernelMutex);
     Kernel *kernel = Kernel::fromHandle(kernelHandle);
     auto it = std::find_if(this->printfKernelContainer.begin(), this->printfKernelContainer.end(), [&kernel](const auto &kernelSharedPtr) { return kernelSharedPtr.get() == kernel; });
     if (it == this->printfKernelContainer.end()) {
@@ -1272,7 +1270,7 @@ bool ModuleImp::linkBinary() {
 }
 
 ze_result_t ModuleImp::getFunctionPointer(const char *pFunctionName, void **pfnFunction) {
-    const auto driverHandle = static_cast<DriverHandleImp *>((this->getDevice())->getDriverHandle());
+    const auto driverHandle = this->getDevice()->getDriverHandle();
     // Check if the function is in the exported symbol table
     auto symbolIt = symbols.find(pFunctionName);
     if ((symbolIt != symbols.end()) && (symbolIt->second.symbol.segment == NEO::SegmentType::instructions)) {
@@ -1309,7 +1307,7 @@ ze_result_t ModuleImp::getFunctionPointer(const char *pFunctionName, void **pfnF
 ze_result_t ModuleImp::getGlobalPointer(const char *pGlobalName, size_t *pSize, void **pPtr) {
     uint64_t address;
     size_t size;
-    const auto driverHandle = static_cast<DriverHandleImp *>((this->getDevice())->getDriverHandle());
+    const auto driverHandle = this->getDevice()->getDriverHandle();
 
     auto hostSymbolIt = hostGlobalSymbolsMap.find(pGlobalName);
     if (hostSymbolIt != hostGlobalSymbolsMap.end()) {
@@ -1346,7 +1344,15 @@ ze_result_t ModuleImp::getGlobalPointer(const char *pGlobalName, size_t *pSize,
 
 Module *Module::create(Device *device, const ze_module_desc_t *desc,
                        ModuleBuildLog *moduleBuildLog, ModuleType type, ze_result_t *result) {
-    auto module = new ModuleImp(device, moduleBuildLog, type);
+    auto usesModuleProgExt = L0::PNextRange(desc->pNext).contains(ZE_STRUCTURE_TYPE_MODULE_PROGRAM_EXP_DESC);
+    bool modulesPackage = usesModuleProgExt && (desc->format == ZE_MODULE_FORMAT_NATIVE);
+
+    Module *module = nullptr;
+    if (modulesPackage) {
+        module = new ModulesPackage(device, moduleBuildLog, type);
+    } else {
+        module = new ModuleImp(device, moduleBuildLog, type);
+    }
 
     *result = module->initialize(desc, device->getNEODevice());
     if (*result != ZE_RESULT_SUCCESS) {
@@ -1490,7 +1496,7 @@ ze_result_t ModuleImp::performDynamicLink(uint32_t numModules,
                                           ze_module_build_log_handle_t *phLinkLog) {
     std::map<void *, std::map<void *, void *>> dependencies;
     ModuleBuildLog *moduleLinkLog = nullptr;
-    const auto driverHandle = static_cast<DriverHandleImp *>((this->getDevice())->getDriverHandle());
+    const auto driverHandle = this->getDevice()->getDriverHandle();
     if (phLinkLog) {
         moduleLinkLog = ModuleBuildLog::create();
         *phLinkLog = moduleLinkLog->toHandle();
@@ -1849,4 +1855,58 @@ size_t ModuleImp::getIsaAllocationPageSize() const {
     }
 }
 
+ze_result_t ModulesPackage::initialize(const ze_module_desc_t *desc, NEO::Device *neoDevice) {
+    L0::PNextRange exts{desc->pNext};
+    auto moduleProgamExt = exts.get<ze_module_program_exp_desc_t>(ZE_STRUCTURE_TYPE_MODULE_PROGRAM_EXP_DESC);
+    UNRECOVERABLE_IF(nullptr == moduleProgamExt);
+    UNRECOVERABLE_IF(ZE_MODULE_FORMAT_NATIVE != desc->format);
+    if (desc->pConstants || moduleProgamExt->pConstants) {
+        return ZE_RESULT_ERROR_INVALID_ARGUMENT;
+    }
+
+    auto baseDesc = *desc;
+    StackVec<ze_module_desc_t, 32> unitsInPackage;
+    if (baseDesc.pInputModule) {
+        unitsInPackage.push_back(baseDesc);
+    }
+    for (decltype(moduleProgamExt->count) i = 0, e = moduleProgamExt->count; i != e; ++i) {
+        baseDesc = *desc;
+        baseDesc.pInputModule = moduleProgamExt->pInputModules[i];
+        baseDesc.inputSize = moduleProgamExt->inputSizes[i];
+        if (moduleProgamExt->pBuildFlags && moduleProgamExt->pBuildFlags[i]) {
+            baseDesc.pBuildFlags = moduleProgamExt->pBuildFlags[i];
+        }
+        unitsInPackage.push_back(baseDesc);
+    }
+
+    for (auto &moduleDesc : unitsInPackage) {
+        auto module = createModuleUnit(this->device, this->packageBuildLog, this->type);
+        auto res = module->initialize(&moduleDesc, neoDevice);
+        if (ZE_RESULT_SUCCESS != res) {
+            return res;
+        }
+        this->modules.push_back(std::move(module));
+    }
+
+    if (this->modules.size() < 2) {
+        this->linkStatus = ZE_RESULT_SUCCESS;
+    } else {
+        StackVec<ze_module_handle_t, 32> modulesToLink;
+        std::transform(modules.begin(), modules.end(), std::back_inserter(modulesToLink),
+                       [](const auto &module) -> ze_module_handle_t { return module.get(); });
+        ze_module_build_log_handle_t linkLog = {};
+        this->linkStatus = this->modules[0]->performDynamicLink(static_cast<uint32_t>(modulesToLink.size()),
+                                                                modulesToLink.data(),
+                                                                this->packageBuildLog ? &linkLog : nullptr);
+        if (linkLog) {
+            UNRECOVERABLE_IF(nullptr == this->packageBuildLog);
+            auto linkLogInternal = ModuleBuildLog::fromHandle(linkLog);
+            append(*this->packageBuildLog, *linkLogInternal);
+            linkLogInternal->destroy();
+        }
+    }
+
+    return this->linkStatus;
+}
+
 } // namespace L0
