@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2025 Intel Corporation
+ * Copyright (C) 2025-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -104,7 +104,7 @@ void MutableKernel::makeKernelResidencySnapshotContainer(bool saveSyncAndRegionA
         uint32_t idx = 0;
         auto kernelImp = static_cast<L0::KernelImp *>(this->kernel);
         for (const auto &allocation : kernel->getInternalResidencyContainer()) {
-            if (idx != kernelImp->getSyncBufferIndex() && idx != kernelImp->getRegionGroupBarrierIndex()) {
+            if (idx != kernelImp->getSyncBufferIndex()) {
                 kernelResidencySnapshotContainer.emplace_back(allocation);
             }
             idx++;
@@ -114,10 +114,6 @@ void MutableKernel::makeKernelResidencySnapshotContainer(bool saveSyncAndRegionA
             this->syncBufferSnapshotResidencyIndex = kernelResidencySnapshotContainer.size();
             kernelResidencySnapshotContainer.emplace_back(this->kernelDispatch->syncBuffer);
         }
-        if (this->kernelDispatch->regionBarrier != nullptr) {
-            this->regionBarrierSnapshotResidencyIndex = kernelResidencySnapshotContainer.size();
-            kernelResidencySnapshotContainer.emplace_back(this->kernelDispatch->regionBarrier);
-        }
     }
 
     // add isa allocation as last to save the indices of other allocations as the same during initial making of snapshot at saveResidencyAllocationIndices call
@@ -136,15 +132,6 @@ void MutableKernel::updateResidencySnapshotContainer() {
             kernelResidencySnapshotContainer.emplace_back(this->kernelDispatch->syncBuffer);
         }
     }
-
-    if (this->kernelDispatch->regionBarrier != nullptr) {
-        if (this->regionBarrierSnapshotResidencyIndex != std::numeric_limits<size_t>::max()) {
-            kernelResidencySnapshotContainer[this->regionBarrierSnapshotResidencyIndex] = this->kernelDispatch->regionBarrier;
-        } else {
-            this->regionBarrierSnapshotResidencyIndex = kernelResidencySnapshotContainer.size();
-            kernelResidencySnapshotContainer.emplace_back(this->kernelDispatch->regionBarrier);
-        }
-    }
 }
 
 bool MutableKernel::checkKernelCompatible() {
