@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2025 Intel Corporation
+ * Copyright (C) 2025-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -23,7 +23,7 @@
 #include "shared/source/program/sync_buffer_handler.h"
 
 #include "level_zero/core/source/cmdlist/cmdlist.h"
-#include "level_zero/core/source/device/device_imp.h"
+#include "level_zero/core/source/device/device.h"
 #include "level_zero/core/source/mutable_cmdlist/mutable_cmdlist_imp.h"
 #include "level_zero/core/source/mutable_cmdlist/mutable_kernel_dispatch.h"
 #include "level_zero/core/source/mutable_cmdlist/variable.h"
@@ -33,25 +33,25 @@ VariableDispatch::VariableDispatch(KernelDispatch *kernelDispatch,
                                    std::unique_ptr<MutableIndirectData> mutableIndirectData, MutableComputeWalker *mutableCommandWalker,
                                    Variable *groupSizeVariable, Variable *groupCountVariable, Variable *globalOffsetVariable, Variable *lastSlmArgumentVariable,
                                    uint32_t grfSize, const MutableKernelDispatchParameters &dispatchParams, uint32_t partitionCount,
-                                   NEO::EngineGroupType cmdListEngineType, bool calculateRegion)
+                                   NEO::EngineGroupType cmdListEngineType)
     : kernelDispatch(kernelDispatch),
       indirectData(std::move(mutableIndirectData)), mutableCommandWalker(mutableCommandWalker),
       groupSizeVar(groupSizeVariable), groupCountVar(groupCountVariable), globalOffsetVar(globalOffsetVariable), lastSlmArgumentVar(lastSlmArgumentVariable),
       perThreadDataSize(dispatchParams.perThreadSize),
-      grfSize(grfSize), walkOrder(dispatchParams.walkOrder), numThreadsPerThreadGroup(dispatchParams.numThreadsPerThreadGroup),
-      threadExecutionMask(dispatchParams.threadExecutionMask), maxWgCountPerTile(dispatchParams.maxWorkGroupCountPerTile), maxCooperativeGroupCount(dispatchParams.maxCooperativeGroupCount),
-      localRegionSize(dispatchParams.localRegionSize), requiredPartitionDim(dispatchParams.requiredPartitionDim), requiredDispatchWalkOrder(dispatchParams.requiredDispatchWalkOrder),
+      grfSize(grfSize), numChannels(kernelDispatch->kernelData->numLocalIdChannels), walkOrder(dispatchParams.walkOrder), numThreadsPerThreadGroup(dispatchParams.numThreadsPerThreadGroup),
+      threadExecutionMask(dispatchParams.threadExecutionMask), maxCooperativeGroupCount(dispatchParams.maxCooperativeGroupCount),
+      requiredPartitionDim(dispatchParams.requiredPartitionDim), requiredDispatchWalkOrder(dispatchParams.requiredDispatchWalkOrder),
       partitionCount(partitionCount), cmdListEngineType(cmdListEngineType),
-      localIdGenerationByRuntime(dispatchParams.generationOfLocalIdsByRuntime), calculateRegion(calculateRegion), isCooperative(dispatchParams.cooperativeDispatch) {
+      localIdGenerationByRuntime(dispatchParams.generationOfLocalIdsByRuntime), isCooperative(dispatchParams.cooperativeDispatch) {
 
     if (groupSizeVar != nullptr) {
-        groupSizeVar->getDesc().size = 3 * sizeof(uint32_t);
+        groupSizeVar->getDesc().size = Constants::maxNumChannels * sizeof(uint32_t);
         groupSizeVar->addDispatch(this);
         groupSizeVar->setGroupSizeProperty(dispatchParams.groupSize);
     }
 
     if (groupCountVar != nullptr) {
-        groupCountVar->getDesc().size = 3 * sizeof(uint32_t);
+        groupCountVar->getDesc().size = Constants::maxNumChannels * sizeof(uint32_t);
         groupCountVar->addDispatch(this);
         groupCountVar->setGroupCountProperty(dispatchParams.groupCount);
 
@@ -64,17 +64,10 @@ VariableDispatch::VariableDispatch(KernelDispatch *kernelDispatch,
             groupCountVar->fillCmdListNoopPatchData(kernelDispatch->syncBufferNoopPatchIndex, noopPtr, noopSize, this->syncBufferOffset, gpuAddress);
             UNRECOVERABLE_IF(noopSize != kernelDispatch->syncBufferSize);
         }
-        if (kernelDispatch->regionBarrierNoopPatchIndex != undefined<size_t>) {
-            void *noopPtr = nullptr;
-            size_t noopSize = 0;
-            uint64_t gpuAddress = 0;
-            groupCountVar->fillCmdListNoopPatchData(kernelDispatch->regionBarrierNoopPatchIndex, noopPtr, noopSize, this->regionBarrierOffset, gpuAddress);
-            UNRECOVERABLE_IF(noopSize != kernelDispatch->regionBarrierSize);
-        }
     }
 
     if (globalOffsetVar != nullptr) {
-        globalOffsetVar->getDesc().size = 3 * sizeof(uint32_t);
+        globalOffsetVar->getDesc().size = Constants::maxNumChannels * sizeof(uint32_t);
         globalOffsetVar->addDispatch(this);
         globalOffsetVar->setGlobalOffsetProperty(dispatchParams.globalOffset);
     }
@@ -83,7 +76,7 @@ VariableDispatch::VariableDispatch(KernelDispatch *kernelDispatch,
         lastSlmArgumentVar->addDispatch(this);
     }
 
-    for (auto dimension = 0u; dimension < numChannels; dimension++) {
+    for (uint32_t dimension = 0u; dimension < Constants::maxNumChannels; dimension++) {
         this->groupSize[dimension] = dispatchParams.groupSize[dimension];
         this->groupCount[dimension] = dispatchParams.groupCount[dimension];
         this->globalOffset[dimension] = dispatchParams.globalOffset[dimension];
@@ -95,13 +88,13 @@ VariableDispatch::VariableDispatch(KernelDispatch *kernelDispatch,
                                                                                                : nullptr;
 
     this->slmTotalSize = kernelDispatch->slmTotalSize;
-    if (calcVar != nullptr && (this->isCooperative || this->calculateRegion) && this->slmTotalSize > 0) {
+    if (calcVar != nullptr && this->isCooperative && this->slmTotalSize > 0) {
         this->alignedSlmSize = calcVar->getAlignedSlmSize(this->slmTotalSize);
     }
 
     if (calcVar != nullptr && this->isCooperative) {
         auto device = calcVar->getCmdList()->getBase()->getDevice();
-        const uint32_t workDim = 3;
+        const uint32_t workDim = Constants::maxNumChannels;
         const size_t localWorkSize[] = {groupSize[0], groupSize[1], groupSize[2]};
         this->maxCooperativeGroupCount = NEO::KernelHelper::getMaxWorkGroupCount(*device->getNEODevice(),
                                                                                  kernelDispatch->kernelData->grfCount,
@@ -119,10 +112,10 @@ VariableDispatch::VariableDispatch(KernelDispatch *kernelDispatch,
     this->isSlmKernel = this->lastSlmArgumentVar != nullptr || this->kernelDispatch->slmInlineSize > 0;
 }
 
-void VariableDispatch::setGroupSize(const uint32_t groupSize[3], NEO::Device &device, bool stageData) {
+void VariableDispatch::setGroupSize(const MaxChannelsCArray groupSize, NEO::Device &device, bool stageData) {
     this->totalLwsSize = 1u;
 
-    for (auto dimension = 0u; dimension < 3; dimension++) {
+    for (uint32_t dimension = 0u; dimension < Constants::maxNumChannels; dimension++) {
         this->groupSize[dimension] = groupSize[dimension];
         this->totalLwsSize *= groupSize[dimension];
     }
@@ -150,7 +143,7 @@ void VariableDispatch::setGroupSize(const uint32_t groupSize[3], NEO::Device &de
     }
 
     if (this->isCooperative) {
-        const uint32_t workDim = 3;
+        const uint32_t workDim = Constants::maxNumChannels;
         const size_t localWorkSize[] = {groupSize[0], groupSize[1], groupSize[2]};
         this->maxCooperativeGroupCount = NEO::KernelHelper::getMaxWorkGroupCount(device,
                                                                                  kernelDispatch->kernelData->grfCount,
@@ -169,15 +162,6 @@ void VariableDispatch::setGroupSize(const uint32_t groupSize[3], NEO::Device &de
         return;
     }
 
-    if (this->calculateRegion) {
-        constexpr uint32_t singleTile = 1;
-        const size_t localWorkSizes[3] = {this->groupSize[0], this->groupSize[1], this->groupSize[2]};
-        this->maxWgCountPerTile = NEO::KernelHelper::getMaxWorkGroupCount(device.getRootDeviceEnvironment(), kernelDispatch->kernelData->grfCount,
-                                                                          kernelDispatch->kernelData->simdSize, kernelDispatch->kernelData->barrierCount, singleTile,
-                                                                          this->alignedSlmSize, numChannels,
-                                                                          localWorkSizes, this->cmdListEngineType);
-    }
-
     if (this->localIdGenerationByRuntime || kernelDispatch->kernelData->numLocalIdChannels == 0) {
         mutableCommandWalker->setGenerateLocalId(false, 0, kernelDispatch->kernelData->numLocalIdChannels);
     } else {
@@ -216,7 +200,6 @@ void VariableDispatch::setGroupSize(const uint32_t groupSize[3], NEO::Device &de
         .slmTotalSize = this->slmTotalSize,
         .slmPolicy = kernelDispatch->slmPolicy,
         .partitionCount = this->partitionCount,
-        .maxWgCountPerTile = this->maxWgCountPerTile,
         .requiredPartitionDim = this->requiredPartitionDim,
         .isRequiredDispatchWorkGroupOrder = this->requiredDispatchWalkOrder != NEO::RequiredDispatchWalkOrder::none,
         .isSlmKernel = this->isSlmKernel,
@@ -227,10 +210,10 @@ void VariableDispatch::setGroupSize(const uint32_t groupSize[3], NEO::Device &de
     mutableCommandWalker->updateSpecificFields(device, args);
 }
 
-void VariableDispatch::setGroupCount(const uint32_t groupCount[3], const NEO::Device &device, bool stageData) {
+void VariableDispatch::setGroupCount(const MaxChannelsCArray groupCount, const NEO::Device &device, bool stageData) {
     this->threadGroupCount = 1;
 
-    for (auto dimension = 0u; dimension < 3; dimension++) {
+    for (uint32_t dimension = 0u; dimension < Constants::maxNumChannels; dimension++) {
         this->groupCount[dimension] = groupCount[dimension];
         this->threadGroupCount *= this->groupCount[dimension];
     }
@@ -283,52 +266,6 @@ void VariableDispatch::setGroupCount(const uint32_t groupCount[3], const NEO::De
         }
     }
 
-    if (kernelDispatch->kernelData->usesRegionGroupBarrier) {
-        auto newSize = NEO::KernelHelper::getRegionGroupBarrierSize(this->threadGroupCount, this->localRegionSize);
-        if (newSize > kernelDispatch->regionBarrierSize) {
-            auto regionBarrierPair = device.syncBufferHandler->obtainAllocationAndOffset(newSize);
-            uint64_t newAddress = regionBarrierPair.first->getGpuAddressToPatch() + regionBarrierPair.second;
-            indirectData->setAddress(kernelDispatch->kernelData->regionGroupBarrierBufferOffset,
-                                     newAddress,
-                                     kernelDispatch->kernelData->regionGroupBarrierBufferPointerSize);
-
-            groupCountVar->updateAllocationResidency(kernelDispatch->regionBarrier, regionBarrierPair.first);
-
-            kernelDispatch->regionBarrierSize = newSize;
-            kernelDispatch->regionBarrier = regionBarrierPair.first;
-            this->regionBarrierOffset = regionBarrierPair.second;
-
-            void *newCpuPtr = ptrOffset(kernelDispatch->regionBarrier->getUnderlyingBuffer(), this->regionBarrierOffset);
-            uint64_t newGpuAddress = kernelDispatch->regionBarrier->getGpuAddressToPatch() + this->regionBarrierOffset;
-            if (kernelDispatch->regionBarrierNoopPatchIndex == undefined<size_t>) {
-                kernelDispatch->regionBarrierNoopPatchIndex = groupCountVar->createNewCmdListNoopPatchData(newCpuPtr, newSize, this->regionBarrierOffset, newGpuAddress);
-            } else {
-                groupCountVar->updateCmdListNoopPatchData(kernelDispatch->regionBarrierNoopPatchIndex, newCpuPtr, newSize, this->regionBarrierOffset, newGpuAddress);
-            }
-        } else {
-            // mutation of kernels - check noop patch needs update and repatch the region barrier address
-            // if new size is not bigger (else branch - here), then region barrier must exists and so noop patch must exists
-            // but noop patch could be reused by other kernel, so at group count mutation must check and update noop patch
-            UNRECOVERABLE_IF(kernelDispatch->regionBarrierNoopPatchIndex == undefined<size_t>);
-
-            void *noopCpuPtr = nullptr;
-            size_t noopSize = 0;
-            size_t noopOffset = 0;
-            uint64_t noopGpuAddress = 0;
-            groupCountVar->fillCmdListNoopPatchData(kernelDispatch->regionBarrierNoopPatchIndex, noopCpuPtr, noopSize, noopOffset, noopGpuAddress);
-
-            void *currentNoopPtr = ptrOffset(kernelDispatch->regionBarrier->getUnderlyingBuffer(), this->regionBarrierOffset);
-            if (noopSize != kernelDispatch->regionBarrierSize || noopOffset != this->regionBarrierOffset || noopCpuPtr != currentNoopPtr) {
-                uint64_t currentKernelPatchGpuAddress = kernelDispatch->regionBarrier->getGpuAddressToPatch() + this->regionBarrierOffset;
-                indirectData->setAddress(kernelDispatch->kernelData->regionGroupBarrierBufferOffset,
-                                         currentKernelPatchGpuAddress,
-                                         kernelDispatch->kernelData->regionGroupBarrierBufferPointerSize);
-
-                groupCountVar->updateCmdListNoopPatchData(kernelDispatch->regionBarrierNoopPatchIndex, currentNoopPtr, kernelDispatch->regionBarrierSize, this->regionBarrierOffset, currentKernelPatchGpuAddress);
-            }
-        }
-    }
-
     if (stageData) {
         this->commitGroupCount = true;
         return;
@@ -349,7 +286,6 @@ void VariableDispatch::setGroupCount(const uint32_t groupCount[3], const NEO::De
         .slmTotalSize = this->slmTotalSize,
         .slmPolicy = kernelDispatch->slmPolicy,
         .partitionCount = this->partitionCount,
-        .maxWgCountPerTile = this->maxWgCountPerTile,
         .requiredPartitionDim = this->requiredPartitionDim,
         .isRequiredDispatchWorkGroupOrder = this->requiredDispatchWalkOrder != NEO::RequiredDispatchWalkOrder::none,
         .isSlmKernel = this->isSlmKernel,
@@ -364,9 +300,9 @@ void VariableDispatch::setGroupCount(const uint32_t groupCount[3], const NEO::De
     indirectData->setNumWorkGroups(this->groupCount);
 }
 
-void VariableDispatch::setGlobalOffset(const uint32_t globalOffset[3]) {
-    for (int i = 0; i < 3; i++) {
-        this->globalOffset[i] = globalOffset[i];
+void VariableDispatch::setGlobalOffset(const MaxChannelsCArray globalOffset) {
+    for (uint32_t dimension = 0; dimension < Constants::maxNumChannels; dimension++) {
+        this->globalOffset[dimension] = globalOffset[dimension];
     }
 
     PRINT_STRING(NEO::debugManager.flags.PrintMclData.get(), stderr, "MCL mutation global offset variable %p new value %u %u %u\n", globalOffsetVar, globalOffset[0], globalOffset[1], globalOffset[2]);
@@ -375,8 +311,8 @@ void VariableDispatch::setGlobalOffset(const uint32_t globalOffset[3]) {
 }
 
 void VariableDispatch::setGws() {
-    std::array<uint32_t, 3> gws;
-    for (auto dimension = 0u; dimension < numChannels; dimension++) {
+    MaxChannelsArray gws = {0, 0, 0};
+    for (uint32_t dimension = 0u; dimension < Constants::maxNumChannels; dimension++) {
         gws[dimension] = groupSize[dimension] * groupCount[dimension];
     }
     PRINT_STRING(NEO::debugManager.flags.PrintMclData.get(), stderr, "MCL mutation set gws %u %u %u\n", gws[0], gws[1], gws[2]);
@@ -395,8 +331,8 @@ void VariableDispatch::setWorkDim() {
 }
 
 bool VariableDispatch::requiresLocalIdGeneration(size_t localWorkSize, uint32_t &outWalkOrder, const NEO::RootDeviceEnvironment &rootDeviceEnvironment) {
-    size_t localWorkSizes[3] = {this->groupSize[0], this->groupSize[1], this->groupSize[2]};
-    std::array<uint8_t, 3> kernelWalkOrder{
+    size_t localWorkSizes[Constants::maxNumChannels] = {this->groupSize[0], this->groupSize[1], this->groupSize[2]};
+    std::array<uint8_t, Constants::maxNumChannels> kernelWalkOrder{
         kernelDispatch->kernelData->workgroupWalkOrder[0],
         kernelDispatch->kernelData->workgroupWalkOrder[1],
         kernelDispatch->kernelData->workgroupWalkOrder[2]};
@@ -421,7 +357,7 @@ void VariableDispatch::generateLocalIds(size_t localWorkSize, const NEO::RootDev
     }
     memset(perThreadData.get(), 0, perThreadDataSize);
 
-    std::array<uint8_t, 3> walkOrder{0, 1, 2};
+    std::array<uint8_t, Constants::maxNumChannels> walkOrder{0, 1, 2};
     if (kernelDispatch->kernelData->requiresWorkgroupWalkOrder) {
         walkOrder = {kernelDispatch->kernelData->workgroupWalkOrder[0],
                      kernelDispatch->kernelData->workgroupWalkOrder[1],
@@ -431,11 +367,11 @@ void VariableDispatch::generateLocalIds(size_t localWorkSize, const NEO::RootDev
     NEO::generateLocalIDs(
         perThreadData.get(),
         static_cast<uint16_t>(simdSize),
-        std::array<uint16_t, 3>{static_cast<uint16_t>(groupSize[0]),
-                                static_cast<uint16_t>(groupSize[1]),
-                                static_cast<uint16_t>(groupSize[2])},
+        std::array<uint16_t, Constants::maxNumChannels>{static_cast<uint16_t>(groupSize[0]),
+                                                        static_cast<uint16_t>(groupSize[1]),
+                                                        static_cast<uint16_t>(groupSize[2])},
         walkOrder,
-        false, grfSize, grfCount, rootDeviceEnvironment);
+        false, grfSize, grfCount, rootDeviceEnvironment, numChannels);
 }
 
 Variable *VariableDispatch::getGroupSizeVar() const { return groupSizeVar; }
@@ -450,12 +386,12 @@ const MutableIndirectData::Offsets &VariableDispatch::getIndirectDataOffsets() c
 
 void VariableDispatch::setSlmSize(const uint32_t slmArgTotalSize, NEO::Device &device, bool stageData) {
     this->slmTotalSize = slmArgTotalSize + kernelDispatch->slmInlineSize;
-    if (this->isCooperative || this->calculateRegion) {
+    if (this->isCooperative) {
         this->alignedSlmSize = device.getGfxCoreHelper().alignSlmSize(this->slmTotalSize);
     }
 
     if (this->isCooperative) {
-        const uint32_t workDim = 3;
+        const uint32_t workDim = Constants::maxNumChannels;
         const size_t localWorkSize[] = {this->groupSize[0], this->groupSize[1], this->groupSize[2]};
         this->maxCooperativeGroupCount = NEO::KernelHelper::getMaxWorkGroupCount(device,
                                                                                  kernelDispatch->kernelData->grfCount,
@@ -474,15 +410,6 @@ void VariableDispatch::setSlmSize(const uint32_t slmArgTotalSize, NEO::Device &d
         return;
     }
 
-    if (this->calculateRegion) {
-        constexpr uint32_t singleTile = 1;
-        const size_t localWorkSizes[3] = {this->groupSize[0], this->groupSize[1], this->groupSize[2]};
-        this->maxWgCountPerTile = NEO::KernelHelper::getMaxWorkGroupCount(device.getRootDeviceEnvironment(), kernelDispatch->kernelData->grfCount,
-                                                                          kernelDispatch->kernelData->simdSize, kernelDispatch->kernelData->barrierCount, singleTile,
-                                                                          this->alignedSlmSize, numChannels,
-                                                                          localWorkSizes, this->cmdListEngineType);
-    }
-
     mutableCommandWalker->updateSlmSize(device, this->slmTotalSize);
     kernelDispatch->slmTotalSize = this->slmTotalSize;
 
@@ -500,7 +427,6 @@ void VariableDispatch::setSlmSize(const uint32_t slmArgTotalSize, NEO::Device &d
         .slmTotalSize = this->slmTotalSize,
         .slmPolicy = kernelDispatch->slmPolicy,
         .partitionCount = this->partitionCount,
-        .maxWgCountPerTile = this->maxWgCountPerTile,
         .requiredPartitionDim = this->requiredPartitionDim,
         .isRequiredDispatchWorkGroupOrder = this->requiredDispatchWalkOrder != NEO::RequiredDispatchWalkOrder::none,
         .isSlmKernel = this->isSlmKernel,
@@ -555,17 +481,6 @@ void VariableDispatch::commitChanges(const NEO::Device &device) {
         kernelDispatch->slmTotalSize = this->slmTotalSize;
     }
 
-    if (this->commitGroupSize || this->commitSlmSize) {
-        if (this->calculateRegion) {
-            constexpr uint32_t singleTile = 1;
-            const size_t localWorkSizes[3] = {this->groupSize[0], this->groupSize[1], this->groupSize[2]};
-            this->maxWgCountPerTile = NEO::KernelHelper::getMaxWorkGroupCount(device.getRootDeviceEnvironment(), kernelDispatch->kernelData->grfCount,
-                                                                              kernelDispatch->kernelData->simdSize, kernelDispatch->kernelData->barrierCount, singleTile,
-                                                                              this->alignedSlmSize, numChannels,
-                                                                              localWorkSizes, this->cmdListEngineType);
-        }
-    }
-
     MutableWalkerSpecificFieldsArguments args{
         .threadGroupDimensions = this->groupCount.data(),
         .threadGroupCount = this->threadGroupCount,
@@ -576,7 +491,6 @@ void VariableDispatch::commitChanges(const NEO::Device &device) {
         .slmTotalSize = this->slmTotalSize,
         .slmPolicy = kernelDispatch->slmPolicy,
         .partitionCount = this->partitionCount,
-        .maxWgCountPerTile = this->maxWgCountPerTile,
         .requiredPartitionDim = this->requiredPartitionDim,
         .isRequiredDispatchWorkGroupOrder = this->requiredDispatchWalkOrder != NEO::RequiredDispatchWalkOrder::none,
         .isSlmKernel = this->isSlmKernel,
