@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2025 Intel Corporation
+ * Copyright (C) 2023-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -463,5 +463,16 @@ bool SysmanKmdInterfaceXe::isLateBindingVersionAvailable(std::string fwType, std
     return result == ZE_RESULT_SUCCESS ? true : false;
 }
 
+bool SysmanKmdInterfaceXe::isDeviceInFdoMode() {
+    std::string survivabilitySysFsNodeName = "device/survivability_info/fdo_mode";
+    std::string survivabilityFdoNodeVal = {};
+    ze_result_t result = pSysfsAccess->read(survivabilitySysFsNodeName, survivabilityFdoNodeVal);
+    if (result != ZE_RESULT_SUCCESS) {
+        PRINT_STRING(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): FsAccess->read() failed to read %s and returning error:0x%x \n", __FUNCTION__, survivabilitySysFsNodeName.c_str(), result);
+        return false;
+    }
+    return survivabilityFdoNodeVal == "enabled";
+}
+
 } // namespace Sysman
 } // namespace L0
