@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2025 Intel Corporation
+ * Copyright (C) 2021-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -20,7 +20,7 @@
 #include "shared/source/os_interface/os_interface.h"
 #include "shared/source/sip_external_lib/sip_external_lib.h"
 
-#include "level_zero/core/source/device/device_imp.h"
+#include "level_zero/core/source/device/device.h"
 #include "level_zero/core/source/gfx_core_helpers/l0_gfx_core_helper.h"
 #include "level_zero/zet_intel_gpu_debug.h"
 
@@ -105,7 +105,6 @@ uint32_t DebugSession::getDeviceIndexFromApiThread(ze_device_thread_t thread) {
 }
 
 ze_device_thread_t DebugSession::convertToPhysicalWithinDevice(ze_device_thread_t thread, uint32_t deviceIndex) {
-    auto deviceImp = static_cast<DeviceImp *>(connectedDevice);
     const auto &topologyMap = getTopologyMap();
 
     // set slice for single slice config to allow subslice remapping
@@ -116,10 +115,10 @@ ze_device_thread_t DebugSession::convertToPhysicalWithinDevice(ze_device_thread_
 
     if (thread.slice != UINT32_MAX) {
         if (thread.subslice != UINT32_MAX) {
-            deviceImp->toPhysicalSliceId(topologyMap, thread.slice, thread.subslice, deviceIndex);
+            connectedDevice->toPhysicalSliceId(topologyMap, thread.slice, thread.subslice, deviceIndex);
         } else {
             uint32_t dummy = 0;
-            deviceImp->toPhysicalSliceId(topologyMap, thread.slice, dummy, deviceIndex);
+            connectedDevice->toPhysicalSliceId(topologyMap, thread.slice, dummy, deviceIndex);
         }
     }
 
@@ -127,21 +126,18 @@ ze_device_thread_t DebugSession::convertToPhysicalWithinDevice(ze_device_thread_
 }
 
 EuThread::ThreadId DebugSession::convertToThreadId(ze_device_thread_t thread) {
-    auto deviceImp = static_cast<DeviceImp *>(connectedDevice);
     UNRECOVERABLE_IF(!DebugSession::isSingleThread(thread));
 
     uint32_t deviceIndex = 0;
-    deviceImp->toPhysicalSliceId(getTopologyMap(), thread.slice, thread.subslice, deviceIndex);
+    connectedDevice->toPhysicalSliceId(getTopologyMap(), thread.slice, thread.subslice, deviceIndex);
 
     EuThread::ThreadId threadId(deviceIndex, thread.slice, thread.subslice, thread.eu, thread.thread);
     return threadId;
 }
 
 ze_device_thread_t DebugSession::convertToApi(EuThread::ThreadId threadId) {
-    auto deviceImp = static_cast<DeviceImp *>(connectedDevice);
-
     ze_device_thread_t thread = {static_cast<uint32_t>(threadId.slice), static_cast<uint32_t>(threadId.subslice), static_cast<uint32_t>(threadId.eu), static_cast<uint32_t>(threadId.thread)};
-    deviceImp->toApiSliceId(getTopologyMap(), thread.slice, thread.subslice, threadId.tileIndex);
+    connectedDevice->toApiSliceId(getTopologyMap(), thread.slice, thread.subslice, threadId.tileIndex);
 
     return thread;
 }
@@ -539,10 +535,9 @@ bool DebugSessionImp::writeResumeCommand(const std::vector<EuThread::ThreadId> &
 bool DebugSessionImp::checkThreadIsResumed(const EuThread::ThreadId &threadID) {
     auto stateSaveAreaHeader = getStateSaveAreaHeader();
     bool resumed = true;
-
-    if (stateSaveAreaHeader->versionHeader.version.major >= 2u) {
+    const auto thread = allThreads[threadID].get();
+    if (stateSaveAreaHeader->versionHeader.version.major > 1 && stateSaveAreaHeader->versionHeader.version.major < 5) {
         SIP::sr_ident srMagic = {{0}};
-        const auto thread = allThreads[threadID].get();
 
         if (!readSystemRoutineIdent(thread, thread->getMemoryHandle(), srMagic)) {
             return resumed;
@@ -554,6 +549,15 @@ bool DebugSessionImp::checkThreadIsResumed(const EuThread::ThreadId &threadID) {
         if (srMagic.count == thread->getLastCounter()) {
             resumed = false;
         }
+    } else if (stateSaveAreaHeader->versionHeader.version.major >= 5) {
+        uint64_t sipCounter = 0;
+        if (!getThreadSipCounter(nullptr, thread, stateSaveAreaHeader, &sipCounter)) {
+            return resumed;
+        }
+        // Counter greater than last one means thread was resumed
+        if (sipCounter == thread->getLastCounter()) {
+            resumed = false;
+        }
     }
     return resumed;
 }
@@ -561,10 +565,10 @@ bool DebugSessionImp::checkThreadIsResumed(const EuThread::ThreadId &threadID) {
 bool DebugSessionImp::checkThreadIsResumed(const EuThread::ThreadId &threadID, const void *stateSaveArea) {
     auto stateSaveAreaHeader = getStateSaveAreaHeader();
     bool resumed = true;
+    const auto thread = allThreads[threadID].get();
 
-    if (stateSaveAreaHeader->versionHeader.version.major >= 2u) {
+    if (stateSaveAreaHeader->versionHeader.version.major > 1 && stateSaveAreaHeader->versionHeader.version.major < 5) {
         SIP::sr_ident srMagic = {{0}};
-        const auto thread = allThreads[threadID].get();
 
         if (!readSystemRoutineIdentFromMemory(thread, stateSaveArea, srMagic)) {
             return resumed;
@@ -576,6 +580,15 @@ bool DebugSessionImp::checkThreadIsResumed(const EuThread::ThreadId &threadID, c
         if (srMagic.count == thread->getLastCounter()) {
             resumed = false;
         }
+    } else if (stateSaveAreaHeader->versionHeader.version.major >= 5) {
+        uint64_t sipCounter = 0;
+        if (!getThreadSipCounter(stateSaveArea, thread, stateSaveAreaHeader, &sipCounter)) {
+            return resumed;
+        }
+        // Counter greater than last one means thread was resumed
+        if (sipCounter == thread->getLastCounter()) {
+            resumed = false;
+        }
     }
     return resumed;
 }
@@ -780,6 +793,7 @@ void DebugSessionImp::addThreadToNewlyStoppedFromRaisedAttention(EuThread::Threa
 
     SIP::sr_ident srMagic = {{0}};
     srMagic.count = 0;
+    auto stateSaveAreaHeader = getStateSaveAreaHeader();
 
     DEBUG_BREAK_IF(stateSaveArea == nullptr);
 
@@ -788,12 +802,20 @@ void DebugSessionImp::addThreadToNewlyStoppedFromRaisedAttention(EuThread::Threa
         wasStopped = allThreads[threadId]->isStopped();
 
         if (!wasStopped) {
-
-            if (!readSystemRoutineIdentFromMemory(allThreads[threadId].get(), stateSaveArea, srMagic)) {
-                PRINT_DEBUGGER_ERROR_LOG("Failed to read SR IDENT\n", "");
-                return;
+            uint64_t counter = 0;
+            if (stateSaveAreaHeader->versionHeader.version.major < 5) {
+                if (!readSystemRoutineIdentFromMemory(allThreads[threadId].get(), stateSaveArea, srMagic)) {
+                    PRINT_DEBUGGER_ERROR_LOG("Failed to read SR IDENT\n", "");
+                    return;
+                } else {
+                    PRINT_DEBUGGER_INFO_LOG("SIP version == %d.%d.%d\n", (int)srMagic.version.major, (int)srMagic.version.minor, (int)srMagic.version.patch);
+                }
             } else {
-                PRINT_DEBUGGER_INFO_LOG("SIP version == %d.%d.%d\n", (int)srMagic.version.major, (int)srMagic.version.minor, (int)srMagic.version.patch);
+                if (!getThreadSipCounter(stateSaveArea, allThreads[threadId].get(), stateSaveAreaHeader, &counter)) {
+                    PRINT_DEBUGGER_ERROR_LOG("Failed to read SIP counter\n", "");
+                    return;
+                }
+                srMagic.count = static_cast<uint8_t>(counter);
             }
 
             if (!allThreads[threadId]->verifyStopped(srMagic.count)) {
