@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -23,6 +23,9 @@ class RasImp : public Ras, NEO::NonCopyableAndNonMovableClass {
     ze_result_t rasGetState(zes_ras_state_t *pConfig, ze_bool_t clear) override;
     ze_result_t rasGetStateExp(uint32_t *pCount, zes_ras_state_exp_t *pState) override;
     ze_result_t rasClearStateExp(zes_ras_error_category_exp_t category) override;
+    ze_result_t rasGetSupportedCategoriesExp(uint32_t *pCount, zes_ras_error_category_exp_t *pCategories) override;
+    ze_result_t rasGetConfigExp(const uint32_t count, zes_intel_ras_config_exp_t *pConfig) override;
+    ze_result_t rasSetConfigExp(const uint32_t count, const zes_intel_ras_config_exp_t *pConfig) override;
 
     RasImp() = default;
     RasImp(OsSysman *pOsSysman, zes_ras_error_type_t type, ze_device_handle_t deviceHandle);
