@@ -22,7 +22,6 @@
 #include "opencl/source/command_queue/command_queue.h"
 #include "opencl/source/command_queue/gpgpu_walker.h"
 #include "opencl/source/helpers/queue_helpers.h"
-#include "opencl/source/kernel/kernel.h"
 #include "opencl/source/program/printf_handler.h"
 
 #include <memory>
@@ -30,6 +29,7 @@
 namespace NEO {
 
 class EventBuilder;
+class Kernel;
 struct EnqueueProperties;
 struct KernelOperation;
 struct MultiDispatchInfo;
@@ -569,5 +569,8 @@ class CommandQueueHw : public CommandQueue {
 
     bool isBlitAuxTranslationRequired(const MultiDispatchInfo &multiDispatchInfo);
     bool relaxedOrderingForGpgpuAllowed(uint32_t numWaitEvents) const;
+    bool isFillOperation(cl_command_type commandType) const {
+        return (commandType == CL_COMMAND_FILL_BUFFER) || (commandType == CL_COMMAND_SVM_MEMFILL);
+    }
 };
 } // namespace NEO
