@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2025 Intel Corporation
+ * Copyright (C) 2018-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -66,7 +66,6 @@ cl_int CommandQueueHw<GfxFamily>::enqueueHandler(Surface *(&surfaces)[surfaceCou
 
     auto auxTranslationMode = AuxTranslationMode::none;
 
-    kernel->updateAuxTranslationRequired();
     if (kernel->isAuxTranslationRequired()) {
         kernelObjsForAuxTranslation = kernel->fillWithKernelObjsForAuxTranslation();
 
@@ -195,15 +194,15 @@ cl_int CommandQueueHw<GfxFamily>::enqueueHandler(Surface **surfacesForResidency,
     }
 
     const bool enqueueWithBlitAuxTranslation = isBlitAuxTranslationRequired(multiDispatchInfo);
-    const auto &hwInfo = this->getDevice().getHardwareInfo();
-    auto &productHelper = getDevice().getProductHelper();
     bool canUsePipeControlInsteadOfSemaphoresForOnCsrDependencies = false;
     bool isNonStallingIoqBarrier = commandType == CL_COMMAND_BARRIER && !isOOQEnabled() && (debugManager.flags.OptimizeIoqBarriersHandling.get() != 0);
     const bool isNonStallingIoqBarrierWithDependencies = isNonStallingIoqBarrier && (eventsRequest.numEventsInWaitList > 0);
 
     if (computeCommandStreamReceiver.peekTimestampPacketWriteEnabled()) {
         canUsePipeControlInsteadOfSemaphoresForOnCsrDependencies = this->peekLatestSentEnqueueOperation() == EnqueueProperties::Operation::gpuKernel &&
-                                                                   productHelper.isResolveDependenciesByPipeControlsSupported(hwInfo, this->isOOQEnabled(), this->taskCount, computeCommandStreamReceiver);
+                                                                   this->isBarrierForImplicitDependenciesAllowed &&
+                                                                   !this->isOOQEnabled() &&
+                                                                   (this->isWalkerPostSyncSkipEnabled || this->taskCount == computeCommandStreamReceiver.peekTaskCount());
         if (false == clearDependenciesForSubCapture) {
             if (false == canUsePipeControlInsteadOfSemaphoresForOnCsrDependencies) {
                 eventsRequest.fillCsrDependenciesForTimestampPacketContainer(csrDeps, computeCommandStreamReceiver, CsrDependencies::DependenciesType::onCsr);
@@ -212,6 +211,7 @@ cl_int CommandQueueHw<GfxFamily>::enqueueHandler(Surface **surfacesForResidency,
         }
         auto allocator = computeCommandStreamReceiver.getTimestampPacketAllocator();
 
+        bool canSkipCurrentPostSync = false;
         size_t nodesCount = 0u;
         if (isCacheFlushCommand(commandType) || isFlushWithPostSyncWrite || isNonStallingIoqBarrierWithDependencies) {
             nodesCount = 1;
@@ -220,8 +220,9 @@ cl_int CommandQueueHw<GfxFamily>::enqueueHandler(Surface **surfacesForResidency,
                 // TSP not needed. Release current node.
                 timestampPacketContainer->moveNodesToNewContainer(*deferredTimestampPackets);
             } else {
-                nodesCount = estimateTimestampPacketNodesCount(multiDispatchInfo);
+                nodesCount = multiDispatchInfo.size();
             }
+            canSkipCurrentPostSync = this->isWalkerPostSyncSkipEnabled && !event;
         }
 
         if (isCacheFlushForBcsRequired() && enqueueWithBlitAuxTranslation) {
@@ -230,7 +231,7 @@ cl_int CommandQueueHw<GfxFamily>::enqueueHandler(Surface **surfacesForResidency,
         }
 
         if (nodesCount > 0) {
-            obtainNewTimestampPacketNodes(nodesCount, timestampPacketDependencies.previousEnqueueNodes, clearAllDependencies, computeCommandStreamReceiver);
+            obtainNewTimestampPacketNodes(canSkipCurrentPostSync ? 0 : nodesCount, timestampPacketDependencies.previousEnqueueNodes, clearAllDependencies, computeCommandStreamReceiver);
             if (false == canUsePipeControlInsteadOfSemaphoresForOnCsrDependencies && timestampPacketDependencies.previousEnqueueNodes.peekNodes().size() > 0) {
                 csrDeps.timestampPacketContainer.push_back(&timestampPacketDependencies.previousEnqueueNodes);
             }
@@ -245,6 +246,11 @@ cl_int CommandQueueHw<GfxFamily>::enqueueHandler(Surface **surfacesForResidency,
         DEBUG_BREAK_IF(relaxedOrderingForGpgpuAllowed(1)); // IOQ has >=1 dependencies
         PipeControlArgs args;
         args.csStallOnly = true;
+        if (timestampPacketDependencies.previousEnqueueNodes.peekNodes().empty()) {
+            auto l1CachePolicy = device->getProductHelper().getL1CachePolicy(this->device->getDebugger() != nullptr);
+            args.isL1FlushRequired = NEO::MemorySynchronizationCommands<GfxFamily>::isL1FlushRequiredForBarrier(l1CachePolicy);
+            args.isL1InvalidateRequired = !args.isL1FlushRequired;
+        }
         args.hdcPipelineFlush = false;
         args.unTypedDataPortCacheFlush = false;
         MemorySynchronizationCommands<GfxFamily>::addSingleBarrier(commandStream, args);
