@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2025 Intel Corporation
+ * Copyright (C) 2018-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -64,7 +64,7 @@ Context::~Context() {
         }
     });
 
-    usmDeviceMemAllocPool.cleanup();
+    usmDeviceMemAllocPoolsManager.cleanup();
 
     delete[] properties;
 
@@ -123,10 +123,11 @@ cl_int Context::tryGetExistingSvmAllocation(const void *ptr,
         if (svmEntry) {
             memoryType = svmEntry->memoryType;
             UsmMemAllocPool *pool = nullptr;
-            if (this->getDevice(0u)->getPlatform()->getHostMemAllocPool().isInPool(ptr)) {
-                pool = &this->getDevice(0u)->getPlatform()->getHostMemAllocPool();
-            } else if (this->getDeviceMemAllocPool().isInPool(ptr)) {
-                pool = &this->getDeviceMemAllocPool();
+            if (memoryType == InternalMemoryType::hostUnifiedMemory) {
+                UsmMemAllocPool *hostAllocPool = &this->getDevice(0u)->getPlatform()->getHostMemAllocPool();
+                pool = hostAllocPool->isInPool(ptr) ? hostAllocPool : nullptr;
+            } else if (memoryType == InternalMemoryType::deviceUnifiedMemory) {
+                pool = this->getDeviceMemAllocPoolsManager().getPoolContainingAlloc(ptr);
             }
             if (pool) {
                 size_t pooledSize = pool->getPooledAllocationSize(ptr);
@@ -524,23 +525,18 @@ void Context::initializeDeviceUsmAllocationPool() {
     }
 
     auto &productHelper = getDevices()[0]->getProductHelper();
-    bool enabled = ApiSpecificConfig::isDeviceUsmPoolingEnabled() &&
-                   productHelper.isDeviceUsmPoolAllocatorSupported() &&
-                   DeviceFactory::isHwModeSelected();
+    bool usmDeviceAllocPoolingEnabled = ApiSpecificConfig::isDeviceUsmPoolingEnabled() &&
+                                        productHelper.isDeviceUsmPoolAllocatorSupported() &&
+                                        DeviceFactory::isHwModeSelected();
 
-    auto usmDevicePoolParams = UsmPoolParams::getUsmPoolParams(getDevices()[0]->getGfxCoreHelper());
     if (debugManager.flags.EnableDeviceUsmAllocationPool.get() != -1) {
-        enabled = debugManager.flags.EnableDeviceUsmAllocationPool.get() > 0;
-        usmDevicePoolParams.poolSize = debugManager.flags.EnableDeviceUsmAllocationPool.get() * MemoryConstants::megaByte;
+        usmDeviceAllocPoolingEnabled = debugManager.flags.EnableDeviceUsmAllocationPool.get() > 0;
     }
-    if (enabled) {
+    if (usmDeviceAllocPoolingEnabled) {
         auto subDeviceBitfields = getDeviceBitfields();
         auto &neoDevice = devices[0]->getDevice();
         subDeviceBitfields[neoDevice.getRootDeviceIndex()] = neoDevice.getDeviceBitfield();
-        UnifiedMemoryProperties memoryProperties(InternalMemoryType::deviceUnifiedMemory, MemoryConstants::pageSize2M,
-                                                 getRootDeviceIndices(), subDeviceBitfields);
-        memoryProperties.device = &neoDevice;
-        usmDeviceMemAllocPool.initialize(svmMemoryManager, memoryProperties, usmDevicePoolParams.poolSize, usmDevicePoolParams.minServicedSize, usmDevicePoolParams.maxServicedSize);
+        this->usmDeviceMemAllocPoolsManager.initialize(InternalMemoryType::deviceUnifiedMemory, rootDeviceIndices, deviceBitfields, &this->devices[0]->getDevice(), svmMemoryManager);
     }
     this->usmPoolInitialized = true;
 }
