@@ -35,7 +35,7 @@
 
 namespace NEO {
 
-BufferFactoryFuncs bufferFactory[IGFX_MAX_CORE] = {};
+BufferFactoryFuncs bufferFactory[NEO::maxCoreEnumValue] = {};
 
 namespace BufferFunctions {
 ValidateInputAndCreateBufferFunc validateInputAndCreateBuffer = Buffer::validateInputAndCreateBuffer;
@@ -208,7 +208,8 @@ bool inline copyHostPointer(Buffer *buffer,
                             size_t size,
                             void *hostPtr,
                             bool implicitScalingEnabled,
-                            cl_int &errcodeRet) {
+                            cl_int &errcodeRet,
+                            GraphicsAllocation *mapAllocation) {
     auto rootDeviceIndex = device.getRootDeviceIndex();
     auto &productHelper = device.getProductHelper();
     auto memory = buffer->getGraphicsAllocation(rootDeviceIndex);
@@ -249,8 +250,7 @@ bool inline copyHostPointer(Buffer *buffer,
             if (blitMemoryToAllocationResult != BlitOperationResult::success) {
                 auto context = buffer->getContext();
                 auto cmdQ = context->getSpecialQueue(rootDeviceIndex);
-                auto mapAllocation = buffer->getMapAllocation(rootDeviceIndex);
-                if (CL_SUCCESS != cmdQ->enqueueWriteBuffer(buffer, CL_TRUE, buffer->getOffset(), size, hostPtr, mapAllocation, 0, nullptr, nullptr)) {
+                if (CL_SUCCESS != cmdQ->enqueueWriteBuffer(buffer, CL_TRUE, 0, size, hostPtr, mapAllocation, 0, nullptr, nullptr)) {
                     errcodeRet = CL_OUT_OF_RESOURCES;
                     return false;
                 }
@@ -303,16 +303,20 @@ Buffer *Buffer::create(Context *context,
         defaultRootDeviceIndex = rootDeviceIndices[0];
         pRootDeviceIndices = &rootDeviceIndices;
     }
-
-    Context::BufferPoolAllocator &bufferPoolAllocator = context->getBufferPoolAllocator();
+    auto poolType = Context::BufferPoolAllocator::getBufferPoolTypeBySize(size);
+    Context::BufferPoolAllocator &bufferPoolAllocator = context->getBufferPoolAllocator(poolType);
     const bool implicitScalingEnabled = ImplicitScalingHelper::isImplicitScalingEnabled(defaultDevice->getDeviceBitfield(), true);
     const bool useHostPtr = memoryProperties.flags.useHostPtr;
     const bool copyHostPtr = memoryProperties.flags.copyHostPtr;
     if (implicitScalingEnabled == false &&
         useHostPtr == false &&
         memoryProperties.flags.forceHostMemory == false &&
+        bufferCreateArgs.isAllocationForPool == false &&
         memoryProperties.associatedDevices.empty()) {
         cl_int poolAllocRet = CL_SUCCESS;
+        if (size <= bufferPoolAllocator.getParams().smallBufferThreshold && bufferPoolAllocator.getPoolType() == Context::BufferPoolType::LargeBuffersPool) {
+            bufferPoolAllocator.initAggregatedSmallBuffers(context);
+        }
         auto bufferFromPool = bufferPoolAllocator.allocateBufferFromPool(memoryProperties,
                                                                          flags,
                                                                          flagsIntel,
@@ -327,7 +331,8 @@ Buffer *Buffer::create(Context *context,
                                 size,
                                 hostPtr,
                                 implicitScalingEnabled,
-                                poolAllocRet);
+                                poolAllocRet,
+                                nullptr);
             }
             if (!needsCopy || poolAllocRet == CL_SUCCESS) {
                 return bufferFromPool;
@@ -424,7 +429,7 @@ Buffer *Buffer::create(Context *context,
             }
         }
 
-        if (!bufferCreateArgs.doNotProvidePerformanceHints && hostPtr && context->isProvidingPerformanceHints()) {
+        if (!bufferCreateArgs.isAllocationForPool && hostPtr && context->isProvidingPerformanceHints()) {
             if (allocationInfo.zeroCopyAllowed) {
                 context->providePerformanceHint(CL_CONTEXT_DIAGNOSTICS_LEVEL_GOOD_INTEL, CL_BUFFER_MEETS_ALIGNMENT_RESTRICTIONS, hostPtr, size);
             } else {
@@ -436,7 +441,7 @@ Buffer *Buffer::create(Context *context,
             allocationInfo.zeroCopyAllowed = false;
         }
 
-        if (!bufferCreateArgs.doNotProvidePerformanceHints && allocationInfo.allocateMemory && context->isProvidingPerformanceHints()) {
+        if (!bufferCreateArgs.isAllocationForPool && allocationInfo.allocateMemory && context->isProvidingPerformanceHints()) {
             context->providePerformanceHint(CL_CONTEXT_DIAGNOSTICS_LEVEL_GOOD_INTEL, CL_BUFFER_NEEDS_ALLOCATE_MEMORY);
         }
 
@@ -568,7 +573,7 @@ Buffer *Buffer::create(Context *context,
                             size,
                             hostPtr,
                             implicitScalingEnabled,
-                            errcodeRet)) {
+                            errcodeRet, allocationInfo.mapAllocation)) {
             auto migrationSyncData = pBuffer->getMultiGraphicsAllocation().getMigrationSyncData();
             if (migrationSyncData) {
                 migrationSyncData->setCurrentLocation(defaultRootDeviceIndex);
