@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2025 Intel Corporation
+ * Copyright (C) 2018-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -17,7 +17,6 @@
 #include "shared/offline_compiler/source/utilities/get_git_version_info.h"
 #include "shared/source/compiler_interface/compiler_cache.h"
 #include "shared/source/compiler_interface/compiler_options.h"
-#include "shared/source/compiler_interface/compiler_options_extra.h"
 #include "shared/source/compiler_interface/default_cache_config.h"
 #include "shared/source/compiler_interface/intermediate_representations.h"
 #include "shared/source/compiler_interface/oclc_extensions.h"
@@ -1001,6 +1000,8 @@ int OfflineCompiler::initialize(size_t numArgs, const std::vector<std::string> &
         return retVal;
     }
 
+    adjustHeaplessMode();
+
     if (formatToEnforce.empty() &&
         compilerProductHelper &&
         compilerProductHelper->oclocEnforceZebinFormat()) {
@@ -1337,6 +1338,12 @@ int OfflineCompiler::parseCommandLine(size_t numArgs, const std::vector<std::str
     return retVal;
 }
 
+void OfflineCompiler::adjustHeaplessMode() {
+    if (this->heaplessMode == CompilerOptions::HeaplessMode::disabled) {
+        hwInfo.featureTable.flags.ftrHeaplessMode = 0;
+    }
+}
+
 void OfflineCompiler::unifyExcludeIrFlags() {
     const auto excludeIrFromZebin{internalOptions.find(CompilerOptions::excludeIrFromZebin.data()) != std::string::npos};
     if (!excludeIr && excludeIrFromZebin) {
