@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -60,15 +60,15 @@ struct EncodePostSyncArgs {
     uint64_t inOrderIncrementValue = 0;
     Device *device = nullptr;
     NEO::InOrderExecInfo *inOrderExecInfo = nullptr;
-    bool isCounterBasedEvent = false;
-    bool isTimestampEvent = false;
     NEO::TagNodeBase *tsNode = nullptr;
-    bool isHostScopeSignalEvent = false;
-    bool isUsingSystemAllocation = false;
     bool dcFlushEnable = false;
     bool interruptEvent = false;
+    bool isCounterBasedEvent = false;
     bool isFlushL3ForExternalAllocationRequired = false;
     bool isFlushL3ForHostUsmRequired = false;
+    bool isHostScopeSignalEvent = false;
+    bool isTimestampEvent = false;
+    bool isUsingSystemAllocation = false;
 
     bool requiresSystemMemoryFence() const;
 
@@ -130,10 +130,8 @@ struct EncodeDispatchKernelArgs {
     PreemptionMode preemptionMode = PreemptionMode::Initial;
     NEO::RequiredPartitionDim requiredPartitionDim = NEO::RequiredPartitionDim::none;
     NEO::RequiredDispatchWalkOrder requiredDispatchWalkOrder = NEO::RequiredDispatchWalkOrder::none;
-    uint32_t localRegionSize = NEO::localRegionSizeParamNotSet;
     uint32_t partitionCount = 0u;
     uint32_t reserveExtraPayloadSpace = 0;
-    uint32_t maxWgCountPerTile = 0;
     int32_t defaultPipelinedThreadArbitrationPolicy = NEO::ThreadArbitrationPolicy::NotPresent;
     bool isIndirect = false;
     bool isPredicate = false;
@@ -175,7 +173,6 @@ struct EncodeWalkerArgs {
     EncodeKernelArgsExt *argsExtended = nullptr;
     KernelExecutionType kernelExecutionType = KernelExecutionType::defaultType;
     NEO::RequiredDispatchWalkOrder requiredDispatchWalkOrder = NEO::RequiredDispatchWalkOrder::none;
-    uint32_t localRegionSize = NEO::localRegionSizeParamNotSet;
     uint32_t maxFrontEndThreads = 0;
     bool requiredSystemFence = false;
     bool hasSample = false;
@@ -282,9 +279,6 @@ struct EncodeDispatchKernel : public EncodeDispatchKernelBase<GfxFamily> {
                                           const uint32_t *threadGroupDimensions, const uint32_t threadGroupCount, const uint32_t requiredThreadGroupDispatchSize,
                                           const uint32_t grfCount, const uint32_t threadsPerThreadGroup, WalkerType &walkerCmd);
 
-    template <typename WalkerType>
-    static void setWalkerRegionSettings(WalkerType &walkerCmd, const NEO::Device &device, uint32_t partitionCount, uint32_t workgroupSize, uint32_t threadGroupCount, uint32_t maxWgCountPerTile, bool requiredDispatchWalkOrder);
-
     template <typename WalkerType>
     static void adjustWalkOrder(WalkerType &walkerCmd, uint32_t requiredWorkGroupOrder, const RootDeviceEnvironment &rootDeviceEnvironment);
 
