@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2025 Intel Corporation
+ * Copyright (C) 2018-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -316,7 +316,8 @@ void CommandStreamReceiver::fillReusableAllocationsList() {
         preallocateCommandBuffer();
     }
 
-    auto internalHeapsToFill = getProductHelper().getInternalHeapsPreallocated();
+    const bool isBcs = EngineHelpers::isBcs(this->osContext->getEngineType());
+    auto internalHeapsToFill = isBcs ? 0u : getProductHelper().getInternalHeapsPreallocated();
     for (auto i = 0u; i < internalHeapsToFill; i++) {
         preallocateInternalHeap();
     }
@@ -759,19 +760,26 @@ void CommandStreamReceiver::createHostFunctionStreamer() {
     auto partitionOffset = this->immWritePostSyncWriteOffset;
     auto tagAddress = this->tagAllocation->getUnderlyingBuffer();
     auto hostFunctionIdAddress = ptrOffset(tagAddress, static_cast<size_t>(TagAllocationLayout::hostFunctionDataOffset));
+    auto dcFlushRequired = this->getDcFlushSupport();
 
-    this->hostFunctionStreamer = std::make_unique<HostFunctionStreamer>(this->tagAllocation,
+    this->hostFunctionStreamer = std::make_unique<HostFunctionStreamer>(this,
+                                                                        this->tagAllocation,
                                                                         hostFunctionIdAddress,
                                                                         this->downloadAllocationImpl,
                                                                         nPartitions,
                                                                         partitionOffset,
-                                                                        isTbxMode());
+                                                                        isTbxMode(),
+                                                                        dcFlushRequired);
 }
 
 HostFunctionStreamer &CommandStreamReceiver::getHostFunctionStreamer() {
     return *hostFunctionStreamer.get();
 }
 
+std::unique_lock<CommandStreamReceiver::MutexType> CommandStreamReceiver::obtainTagAllocationDownloadLock() {
+    return std::unique_lock<CommandStreamReceiver::MutexType>(this->tagAllocationDownloadMutex);
+}
+
 IndirectHeap &CommandStreamReceiver::getIndirectHeap(IndirectHeap::Type heapType,
                                                      size_t minRequiredSize) {
     DEBUG_BREAK_IF(static_cast<uint32_t>(heapType) >= arrayCount(indirectHeap));
@@ -1052,7 +1060,7 @@ bool CommandStreamReceiver::createAllocationForHostSurface(HostPtrSurface &surfa
     if (allocation == nullptr) {
         return false;
     }
-    allocation->hostPtrTaskCountAssignment++;
+    allocation->incrementHostPtrTaskCountAssignment();
     allocation->updateTaskCount(0u, osContext->getContextId());
     surface.setAllocation(allocation.get());
     internalAllocationStorage->storeAllocation(std::move(allocation), TEMPORARY_ALLOCATION);
