@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2025 Intel Corporation
+ * Copyright (C) 2018-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -591,6 +591,8 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
         this->hostFunctionWorker = hostFunctionWorker;
     }
 
+    [[nodiscard]] std::unique_lock<MutexType> obtainTagAllocationDownloadLock();
+
   protected:
     MOCKABLE_VIRTUAL void startHostFunctionWorker();
 
@@ -640,6 +642,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     MutexType hostPtrSurfaceCreationMutex;
     MutexType registeredClientsMutex;
     MutexType hostFunctionWorkerStartMutex;
+    MutexType tagAllocationDownloadMutex;
     ExecutionEnvironment &executionEnvironment;
 
     LinearStream commandStream;
