@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2025 Intel Corporation
+ * Copyright (C) 2025-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -47,12 +47,14 @@ inline constexpr int32_t unlimitedThreads = -1; // each CSR that uses host funct
 
 class HostFunctionStreamer {
   public:
-    HostFunctionStreamer(GraphicsAllocation *allocation,
+    HostFunctionStreamer(CommandStreamReceiver *csr,
+                         GraphicsAllocation *allocation,
                          void *hostFunctionIdAddress,
                          const std::function<void(GraphicsAllocation &)> &downloadAllocationImpl,
                          uint32_t activePartition,
                          uint32_t partitionOffset,
-                         bool isTbx);
+                         bool isTbx,
+                         bool dcFlushRequired);
     ~HostFunctionStreamer() = default;
 
     uint64_t getHostFunctionReadyToExecute() const;
@@ -60,7 +62,7 @@ class HostFunctionStreamer {
     HostFunction getHostFunction(uint64_t hostFunctionId);
     uint64_t getHostFunctionId(uint32_t partitionId) const;
     uint64_t getHostFunctionIdGpuAddress(uint32_t partitionId) const;
-    volatile uint64_t *getHostFunctionIdPtr(uint32_t partitionId) const;
+    uint64_t *getHostFunctionIdPtr(uint32_t partitionId) const;
     uint64_t getNextHostFunctionIdAndIncrement();
 
     void addHostFunction(uint64_t hostFunctionId, HostFunction &&hostFunction);
@@ -68,8 +70,10 @@ class HostFunctionStreamer {
     void signalHostFunctionCompletion(const HostFunction &hostFunction);
     void prepareForExecution(const HostFunction &hostFunction);
     uint32_t getActivePartitions() const;
+    bool getDcFlushRequired() const;
 
   private:
+    void updateTbxData();
     void setHostFunctionIdAsCompleted();
     void startInOrderExecution();
     void endInOrderExecution();
@@ -77,7 +81,8 @@ class HostFunctionStreamer {
 
     std::mutex hostFunctionsMutex;
     std::unordered_map<uint64_t, HostFunction> hostFunctions;
-    volatile uint64_t *hostFunctionIdAddress = nullptr; // 0 bit - used to signal that host function is pending or completed
+    uint64_t *hostFunctionIdAddress = nullptr; // 0 bit - used to signal that host function is pending or completed
+    CommandStreamReceiver *csr = nullptr;
     GraphicsAllocation *allocation = nullptr;
     std::function<void(GraphicsAllocation &)> downloadAllocationImpl;
     std::atomic<uint64_t> nextHostFunctionId{1};
@@ -86,6 +91,7 @@ class HostFunctionStreamer {
     uint32_t partitionOffset{0};
     std::atomic<bool> inOrderExecutionInProgress{false};
     const bool isTbx = false;
+    bool dcFlushRequired = false;
 };
 
 enum class HostFunctionWorkerMode : int32_t {
@@ -96,8 +102,8 @@ enum class HostFunctionWorkerMode : int32_t {
 
 template <typename GfxFamily>
 struct HostFunctionHelper {
-    static void programHostFunction(LinearStream &commandStream, HostFunctionStreamer &streamer, HostFunction &&hostFunction);
-    static void programHostFunctionId(LinearStream *commandStream, void *cmdBuffer, HostFunctionStreamer &streamer, HostFunction &&hostFunction);
+    static void programHostFunction(LinearStream &commandStream, HostFunctionStreamer &streamer, HostFunction &&hostFunction, bool isMemorySynchronizationRequired);
+    static void programHostFunctionId(LinearStream *commandStream, void *cmdBuffer, HostFunctionStreamer &streamer, HostFunction &&hostFunction, bool isMemorySynchronizationRequired);
     static void programHostFunctionWaitForCompletion(LinearStream *commandStream, void *cmdBuffer, const HostFunctionStreamer &streamer, uint32_t partionId);
 };
 
