@@ -1,12 +1,12 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
-#include <stdint.h>
+#include <cstdint>
 
 using TaskCountType = uint64_t;
-using TagAddressType = uint64_t;
\ No newline at end of file
+using TagAddressType = uint64_t;
