@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2025 Intel Corporation
+ * Copyright (C) 2018-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -49,7 +49,8 @@ Device::Device(ExecutionEnvironment *executionEnvironment, const uint32_t rootDe
       isaPoolAllocator(this),
       deviceTimestampPoolAllocator(this),
       globalSurfacePoolAllocator(this),
-      constantSurfacePoolAllocator(this) {
+      constantSurfacePoolAllocator(this),
+      commandBufferPoolAllocator(this) {
     this->executionEnvironment->incRefInternal();
     this->executionEnvironment->rootDeviceEnvironments[rootDeviceIndex]->setDummyBlitProperties(rootDeviceIndex);
     debugger = this->executionEnvironment->rootDeviceEnvironments[rootDeviceIndex]->debugger.get();
@@ -83,6 +84,7 @@ Device::~Device() {
     deviceTimestampPoolAllocator.releasePools();
     globalSurfacePoolAllocator.releasePools();
     constantSurfacePoolAllocator.releasePools();
+    commandBufferPoolAllocator.releasePools();
     if (deviceUsmMemAllocPoolsManager) {
         deviceUsmMemAllocPoolsManager->cleanup();
     }
@@ -427,7 +429,7 @@ bool Device::createEngines() {
 
                 auto primaryEngine = engineGroup->engines[engineIndex];
 
-                createSecondaryContexts(primaryEngine, secondaryEnginesForType, contextCount, contextCount - highPriorityContextCount, highPriorityContextCount);
+                createSecondaryContexts(primaryEngine, secondaryEnginesForType, contextCount, highPriorityContextCount);
             }
         }
 
@@ -448,7 +450,7 @@ bool Device::createEngines() {
                     contextCount = std::max(contextCount / numProcesses, 2u);
                 }
 
-                createSecondaryContexts(primaryEngine, secondaryEnginesForType, contextCount, 0, contextCount);
+                createSecondaryContexts(primaryEngine, secondaryEnginesForType, contextCount, contextCount);
             }
         }
     }
@@ -456,8 +458,9 @@ bool Device::createEngines() {
     return true;
 }
 
-void Device::createSecondaryContexts(const EngineControl &primaryEngine, SecondaryContexts &secondaryEnginesForType, uint32_t contextCount, uint32_t regularPriorityCount, uint32_t highPriorityContextCount) {
-    secondaryEnginesForType.regularEnginesTotal = contextCount - highPriorityContextCount;
+void Device::createSecondaryContexts(const EngineControl &primaryEngine, SecondaryContexts &secondaryEnginesForType, uint32_t contextCount, uint32_t highPriorityContextCount) {
+    auto regularContextCount = contextCount - highPriorityContextCount;
+    secondaryEnginesForType.regularEnginesTotal = regularContextCount;
     secondaryEnginesForType.highPriorityEnginesTotal = highPriorityContextCount;
     secondaryEnginesForType.regularCounter = 0;
     secondaryEnginesForType.highPriorityCounter = 0;
@@ -470,16 +473,21 @@ void Device::createSecondaryContexts(const EngineControl &primaryEngine, Seconda
     UNRECOVERABLE_IF(engineTypeUsage.second != EngineUsage::regular && engineTypeUsage.second != EngineUsage::highPriority);
 
     secondaryEnginesForType.engines.push_back(primaryEngine);
-
     for (uint32_t i = 1; i < contextCount; i++) {
 
-        if (i >= contextCount - highPriorityContextCount) {
+        if (i >= regularContextCount) {
             engineTypeUsage.second = EngineUsage::highPriority;
         }
         this->createSecondaryEngine(primaryEngine.commandStreamReceiver, engineTypeUsage);
+        if (regularContextCount == 0) {
+            this->secondaryCsrs.back()->getOsContext().setExclusivelyHpContext();
+        }
     }
 
     UNRECOVERABLE_IF(primaryEngine.osContext->isPartOfContextGroup() == false);
+    if (regularContextCount == 0) {
+        primaryEngine.osContext->setExclusivelyHpContext();
+    }
 }
 
 void Device::allocateDebugSurface(size_t debugSurfaceSize) {
@@ -511,7 +519,7 @@ void Device::addEngineToEngineGroup(EngineControl &engine) {
         return;
     }
 
-    if (EngineHelper::isCopyOnlyEngineType(engineGroupType) && debugManager.flags.EnableBlitterOperationsSupport.get() == 0) {
+    if (EngineHelper::isCopyOnlyEngineType(engineGroupType) && !hardwareInfo.capabilityTable.blitterOperationsSupported) {
         return;
     }
 
@@ -568,7 +576,7 @@ bool Device::createEngine(EngineTypeUsage engineTypeUsage) {
     osContext->setIsPrimaryEngine(isPrimaryEngine);
     osContext->setIsDefaultEngine(isDefaultEngine);
     if (isPrimaryEngine) {
-        osContext->overridePriority(gfxCoreHelper.getLowestQueuePriorityLevel());
+        osContext->overridePriority(gfxCoreHelper.getHwQueuePriority(gfxCoreHelper.getLowestQueuePriorityLevel()));
     }
     DEBUG_BREAK_IF(getDeviceBitfield().count() > 1 && !osContext->isRootDevice());
 
@@ -662,21 +670,21 @@ bool Device::createSecondaryEngine(CommandStreamReceiver *primaryCsr, EngineType
     return true;
 }
 
-EngineControl *Device::getSecondaryEngineCsr(EngineTypeUsage engineTypeUsage, std::optional<int> priorityLevel, bool allocateInterrupt) {
+EngineControl *Device::getSecondaryEngineCsr(EngineTypeUsage engineTypeUsage, std::optional<uint32_t> hwPriority, bool allocateInterrupt) {
     if (secondaryEngines.find(engineTypeUsage.first) == secondaryEngines.end()) {
         return nullptr;
     }
 
     auto &secondaryEnginesForType = secondaryEngines[engineTypeUsage.first];
 
-    auto engineControl = secondaryEnginesForType.getEngine(engineTypeUsage.second, priorityLevel);
+    auto engineControl = secondaryEnginesForType.getEngine(engineTypeUsage.second, hwPriority);
 
     bool isPrimaryContextInGroup = engineControl->osContext->getIsPrimaryEngine() && engineControl->osContext->isPartOfContextGroup();
 
     if (isPrimaryContextInGroup && allocateInterrupt) {
         // Context 0 is already pre-initialized. We need non-initialized context, to pass context creation flag.
         // If all contexts are already initialized, just take next available. Interrupt request is only a hint.
-        engineControl = secondaryEnginesForType.getEngine(engineTypeUsage.second, priorityLevel);
+        engineControl = secondaryEnginesForType.getEngine(engineTypeUsage.second, hwPriority);
     }
 
     isPrimaryContextInGroup = engineControl->osContext->getIsPrimaryEngine() && engineControl->osContext->isPartOfContextGroup();
@@ -1284,12 +1292,12 @@ const EngineGroupT *Device::tryGetRegularEngineGroup(EngineGroupType engineGroup
     return nullptr;
 }
 
-EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int> priorityLevel) {
+EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<uint32_t> hwPriority) {
     auto secondaryEngineIndex = 0;
 
     std::lock_guard<std::mutex> guard(mutex);
 
-    auto findMatchingPriority = [&](const std::vector<int32_t> &indices, int requested, int fallback) -> uint32_t {
+    auto findMatchingPriority = [&](const std::vector<int32_t> &indices, uint32_t requested, int fallback) -> uint32_t {
         for (uint32_t i = 0; i < indices.size(); i++) {
             uint32_t matching = indices[i];
             if (engines[matching].osContext->hasPriorityLevel() &&
@@ -1321,8 +1329,8 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
             auto index = (highPriorityCounter.fetch_add(1)) % (hpIndices.size());
             secondaryEngineIndex = hpIndices[index];
             // Prefer matching priority when reusing an initialized HP context
-            if (priorityLevel.has_value()) {
-                const int requested = priorityLevel.value();
+            if (hwPriority.has_value()) {
+                const int requested = hwPriority.value();
                 secondaryEngineIndex = findMatchingPriority(hpIndices, requested, secondaryEngineIndex);
             }
         }
@@ -1335,8 +1343,8 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
         if (regularEnginesTotal == 0) {
             return nullptr;
         }
-        bool isSamePriorityLevel = (priorityLevel.has_value() && engines[secondaryEngineIndex].osContext->hasPriorityLevel())
-                                       ? (priorityLevel.value() == engines[secondaryEngineIndex].osContext->getPriorityLevel())
+        bool isSamePriorityLevel = (hwPriority.has_value() && engines[secondaryEngineIndex].osContext->hasPriorityLevel())
+                                       ? (hwPriority.value() == engines[secondaryEngineIndex].osContext->getPriorityLevel())
                                        : true;
         if (npIndices.size() == 0 && isSamePriorityLevel) {
             regularCounter.fetch_add(1);
@@ -1353,8 +1361,8 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
             auto index = (regularCounter.fetch_add(1)) % (npIndices.size());
             secondaryEngineIndex = npIndices[index];
             // Prefer matching priority when reusing an initialized regular context
-            if (priorityLevel.has_value()) {
-                const int requested = priorityLevel.value();
+            if (hwPriority.has_value()) {
+                const int requested = hwPriority.value();
                 secondaryEngineIndex = findMatchingPriority(npIndices, requested, secondaryEngineIndex);
             }
         }
@@ -1362,12 +1370,12 @@ EngineControl *SecondaryContexts::getEngine(EngineUsage usage, std::optional<int
         DEBUG_BREAK_IF(true);
     }
 
-    if (priorityLevel.has_value()) {
-        engines[secondaryEngineIndex].osContext->overridePriority(priorityLevel.value());
+    if (hwPriority.has_value()) {
+        engines[secondaryEngineIndex].osContext->overridePriority(hwPriority.value());
     }
     if (debugManager.flags.PrintSecondaryContextEngineInfo.get()) {
         std::stringstream contextEngineInfo;
-        contextEngineInfo << "SecondaryContexts::getEngine-> engineUsage: " << EngineHelpers::engineUsageToString(usage).c_str() << " index: " << secondaryEngineIndex << " priorityLevel: " << (engines[secondaryEngineIndex].osContext->hasPriorityLevel() ? std::to_string(engines[secondaryEngineIndex].osContext->getPriorityLevel()) : "std::nullopt") << " \n";
+        contextEngineInfo << "SecondaryContexts::getEngine-> engineType: " << EngineHelpers::engineTypeToString(engines[secondaryEngineIndex].getEngineType()).c_str() << " engineUsage: " << EngineHelpers::engineUsageToString(usage).c_str() << " index: " << secondaryEngineIndex << " osContext->priorityLevel: " << (engines[secondaryEngineIndex].osContext->hasPriorityLevel() ? std::to_string(engines[secondaryEngineIndex].osContext->getPriorityLevel()) : "std::nullopt") << " \n";
         PRINT_STRING(debugManager.flags.PrintSecondaryContextEngineInfo.get(), stdout, "%s", contextEngineInfo.str().c_str());
     }
     return &engines[secondaryEngineIndex];
