@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2025 Intel Corporation
+ * Copyright (C) 2018-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -216,6 +216,9 @@ class GfxCoreHelper {
     virtual bool crossEngineCacheFlushRequired() const = 0;
     int32_t getHighestQueuePriorityLevel() const;
     int32_t getLowestQueuePriorityLevel() const;
+    int32_t getDefaultQueuePriorityLevel() const;
+    virtual uint32_t getHwQueuePriority(int32_t apiPriority) const = 0;
+    virtual bool isWalkerPostSyncSkipEnabled(bool isBarrierUsedForImplicitDependency) const = 0;
 
     virtual ~GfxCoreHelper() = default;
 
@@ -475,11 +478,14 @@ class GfxCoreHelperHw : public GfxCoreHelper {
     bool isCacheFlushPriorImageReadRequired() const override;
 
     uint32_t getQueuePriorityLevels() const override;
+    uint32_t getHwQueuePriority(int32_t apiPriority) const override;
 
     bool isExtendedUsmPoolSizeEnabled() const override;
 
     bool crossEngineCacheFlushRequired() const override;
 
+    bool isWalkerPostSyncSkipEnabled(bool isBarrierUsedForImplicitDependency) const override;
+
     ~GfxCoreHelperHw() override = default;
 
   protected:
@@ -541,6 +547,7 @@ struct MemorySynchronizationCommands {
 
     static bool isBarrierWaRequired(const RootDeviceEnvironment &rootDeviceEnvironment);
     static bool isBarrierPriorToPipelineSelectWaRequired(const RootDeviceEnvironment &rootDeviceEnvironment);
+    static bool isL1FlushRequiredForBarrier(uint32_t l1CachePolicy);
     static void setBarrierExtraProperties(void *barrierCmd, PipeControlArgs &args);
 
     static void encodeAdditionalTimestampOffsets(LinearStream &commandStream, uint64_t contextAddress, uint64_t globalAddress, bool isBcs);
