@@ -6,14 +6,16 @@
  */
 
 #pragma once
-#include "shared/source/helpers/constants.h"
+
+#include "shared/source/indirect_heap/indirect_heap_type.h"
+
+#include <cstddef>
 
 namespace NEO {
 namespace HeapSize {
 
-inline constexpr size_t defaultHeapSize = 64 * MemoryConstants::kiloByte;
-
-size_t getDefaultHeapSize(size_t defaultValue);
+size_t getDefaultHeapSize(IndirectHeapType heapType);
+size_t getHeapSize(size_t defaultValue);
 
 } // namespace HeapSize
 } // namespace NEO
