@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2025 Intel Corporation
+ * Copyright (C) 2023-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -15,8 +15,8 @@
 #include "shared/source/utilities/heap_allocator.h"
 #include "shared/source/utilities/sorted_vector.h"
 
+#include <functional>
 #include <map>
-
 namespace NEO {
 class GraphicsAllocation;
 class MemoryManager;
@@ -38,6 +38,7 @@ class UsmMemAllocPool : NEO::NonCopyableAndNonMovableClass {
         evict
     };
     using AllocationsInfoStorage = BaseSortedPointerWithValueVector<AllocationInfo>;
+    using CustomCleanupFn = std::function<void(const void *)>;
 
     UsmMemAllocPool() = default;
     MOCKABLE_VIRTUAL ~UsmMemAllocPool() = default;
@@ -85,12 +86,17 @@ class UsmMemAllocPool : NEO::NonCopyableAndNonMovableClass {
         }
     }
 
+    void setCustomCleanup(CustomCleanupFn customCleanup) {
+        this->customCleanup = std::move(customCleanup);
+    }
+
     static constexpr auto chunkAlignment = 512u;
     static constexpr auto poolAlignment = MemoryConstants::pageSize2M;
 
   protected:
     MemoryOperationsStatus evictPool();
     MemoryOperationsStatus makePoolResident();
+    CustomCleanupFn customCleanup = nullptr;
     std::unique_ptr<HeapAllocator> chunkAllocator;
     void *pool{};
     void *poolEnd{};
@@ -111,6 +117,7 @@ class UsmMemAllocPool : NEO::NonCopyableAndNonMovableClass {
 
 class UsmMemAllocPoolsManager : NEO::NonCopyableAndNonMovableClass {
   public:
+    using CustomCleanupFn = UsmMemAllocPool::CustomCleanupFn;
     static constexpr size_t maxEmptyPoolsPerBucket = 1u;
 
     UsmMemAllocPoolsManager(InternalMemoryType memoryType,
@@ -135,9 +142,13 @@ class UsmMemAllocPoolsManager : NEO::NonCopyableAndNonMovableClass {
     size_t getOffsetInPool(const void *ptr);
     UsmMemAllocPool *getPoolContainingAlloc(const void *ptr);
     void enableResidencyTracking() { this->trackResidency = true; }
+    void setCustomCleanup(CustomCleanupFn customCleanup) {
+        this->customCleanup = std::move(customCleanup);
+    }
 
   protected:
     bool canBePooled(size_t size, const UnifiedMemoryProperties &memoryProperties);
+    CustomCleanupFn customCleanup = nullptr;
     SVMAllocsManager *svmMemoryManager{};
     MemoryManager *memoryManager{};
     Device *device{nullptr};
@@ -149,4 +160,20 @@ class UsmMemAllocPoolsManager : NEO::NonCopyableAndNonMovableClass {
     bool trackResidency{false};
 };
 
+class UsmMemAllocPoolsFacade : NEO::NonCopyableAndNonMovableClass {
+  public:
+    bool initialize(InternalMemoryType memoryType, const RootDeviceIndicesContainer &rootDeviceIndices, const std::map<uint32_t, DeviceBitfield> &subdeviceBitfields, Device *device, SVMAllocsManager *svmMemoryManager);
+    bool isInitialized() const;
+    void cleanup();
+    void *createUnifiedMemoryAllocation(size_t size, const UnifiedMemoryProperties &memoryProperties);
+    bool freeSVMAlloc(const void *ptr, bool blocking);
+    size_t getPooledAllocationSize(const void *ptr);
+    void *getPooledAllocationBasePtr(const void *ptr);
+    UsmMemAllocPool *getPoolContainingAlloc(const void *ptr);
+
+  protected:
+    std::unique_ptr<UsmMemAllocPool> pool;
+    std::unique_ptr<UsmMemAllocPoolsManager> poolManager;
+};
+
 } // namespace NEO
