@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2025 Intel Corporation
+ * Copyright (C) 2018-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,6 +8,7 @@
 #pragma once
 #include "shared/source/command_stream/task_count_helper.h"
 #include "shared/source/helpers/common_types.h"
+#include "shared/source/release_helper/release_helper.h"
 
 #include "aubstream/engine_node.h"
 #include "neo_igfxfmid.h"
@@ -26,6 +27,7 @@ class AubManager;
 namespace NEO {
 struct KmdNotifyProperties;
 struct AllocationData;
+struct BlitProperties;
 class CommandStreamReceiver;
 class Device;
 class Drm;
@@ -171,13 +173,12 @@ class ProductHelper {
     virtual bool isUnlockingLockedPtrNecessary(const HardwareInfo &hwInfo) const = 0;
     virtual bool isAdjustWalkOrderAvailable(const ReleaseHelper *releaseHelper) const = 0;
     virtual uint32_t getL1CachePolicy(bool isDebuggerActive) const = 0;
-    virtual bool isEvictionIfNecessaryFlagSupported() const = 0;
     virtual void adjustNumberOfCcs(HardwareInfo &hwInfo) const = 0;
     virtual bool blitEnqueuePreferred(bool isWriteToImageFromBuffer) const = 0;
     virtual bool isPrefetcherDisablingInDirectSubmissionRequired() const = 0;
     virtual bool isStatefulAddressingModeSupported() const = 0;
     virtual bool isPlatformQuerySupported() const = 0;
-    virtual bool isResolveDependenciesByPipeControlsSupported(const HardwareInfo &hwInfo, bool isOOQ, TaskCountType queueTaskCount, const CommandStreamReceiver &queueCsr) const = 0;
+    virtual bool isResolveDependenciesByPipeControlsSupported() const = 0;
     virtual bool isBufferPoolAllocatorSupported() const = 0;
     virtual bool isHostUsmPoolAllocatorSupported() const = 0;
     virtual bool isDeviceUsmPoolAllocatorSupported() const = 0;
@@ -237,7 +238,7 @@ class ProductHelper {
     virtual bool isSkippingStatefulInformationRequired(const KernelDescriptor &kernelDescriptor) const = 0;
     virtual bool isResolvingSubDeviceIDNeeded(const ReleaseHelper *releaseHelper) const = 0;
     virtual uint64_t overridePatIndex(bool isUncachedType, uint64_t patIndex, AllocationType allocationType) const = 0;
-    virtual std::vector<uint32_t> getSupportedNumGrfs(const ReleaseHelper *releaseHelper) const = 0;
+    virtual const SupportedNumGrfs getSupportedNumGrfs(const ReleaseHelper *releaseHelper) const = 0;
     virtual aub_stream::EngineType getDefaultCopyEngine() const = 0;
     virtual void adjustEngineGroupType(EngineGroupType &engineGroupType) const = 0;
     virtual std::optional<GfxMemoryAllocationMethod> getPreferredAllocationMethod(AllocationType allocationType) const = 0;
@@ -270,6 +271,7 @@ class ProductHelper {
     virtual bool isCompressionForbidden(const HardwareInfo &hwInfo) const = 0;
     virtual bool isExposingSubdevicesAllowed() const = 0;
     virtual bool useAdditionalBlitProperties() const = 0;
+    virtual bool useAdditionalBlitProperties(const BlitProperties &blitProperties) const = 0;
     virtual bool isFlushBetweenBlitsRequired() const = 0;
     virtual bool isNonCoherentTimestampsModeEnabled() const = 0;
     virtual bool isPackedCopyFormatSupported() const = 0;
