@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2025 Intel Corporation
+ * Copyright (C) 2023-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -111,13 +111,12 @@ class ProductHelperHw : public ProductHelper {
     bool isUnlockingLockedPtrNecessary(const HardwareInfo &hwInfo) const override;
     bool isAdjustWalkOrderAvailable(const ReleaseHelper *releaseHelper) const override;
     uint32_t getL1CachePolicy(bool isDebuggerActive) const override;
-    bool isEvictionIfNecessaryFlagSupported() const override;
     void adjustNumberOfCcs(HardwareInfo &hwInfo) const override;
     bool isPrefetcherDisablingInDirectSubmissionRequired() const override;
     bool isStatefulAddressingModeSupported() const override;
     uint32_t getNumberOfPartsInTileForConcurrentKernel(uint32_t ccsCount) const override;
     bool isPlatformQuerySupported() const override;
-    bool isResolveDependenciesByPipeControlsSupported(const HardwareInfo &hwInfo, bool isOOQ, TaskCountType queueTaskCount, const CommandStreamReceiver &queueCsr) const override;
+    bool isResolveDependenciesByPipeControlsSupported() const override;
     bool isBufferPoolAllocatorSupported() const override;
     bool isHostUsmPoolAllocatorSupported() const override;
     bool isDeviceUsmPoolAllocatorSupported() const override;
@@ -174,7 +173,7 @@ class ProductHelperHw : public ProductHelper {
     bool isSkippingStatefulInformationRequired(const KernelDescriptor &kernelDescriptor) const override;
     bool isResolvingSubDeviceIDNeeded(const ReleaseHelper *releaseHelper) const override;
     uint64_t overridePatIndex(bool isUncachedType, uint64_t patIndex, AllocationType allocationType) const override;
-    std::vector<uint32_t> getSupportedNumGrfs(const ReleaseHelper *releaseHelper) const override;
+    const SupportedNumGrfs getSupportedNumGrfs(const ReleaseHelper *releaseHelper) const override;
     aub_stream::EngineType getDefaultCopyEngine() const override;
     void adjustEngineGroupType(EngineGroupType &engineGroupType) const override;
     std::optional<GfxMemoryAllocationMethod> getPreferredAllocationMethod(AllocationType allocationType) const override;
@@ -207,6 +206,7 @@ class ProductHelperHw : public ProductHelper {
     bool isCompressionForbidden(const HardwareInfo &hwInfo) const override;
     bool isExposingSubdevicesAllowed() const override;
     bool useAdditionalBlitProperties() const override;
+    bool useAdditionalBlitProperties(const BlitProperties &blitProperties) const override;
     bool isFlushBetweenBlitsRequired() const override;
     bool isNonCoherentTimestampsModeEnabled() const override;
     bool getStorageInfoLocalOnlyFlag(LocalMemAllocationMode usmDeviceAllocationMode, bool defaultValue) const override;
