@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2025 Intel Corporation
+ * Copyright (C) 2025-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -27,6 +27,15 @@ static EnableGfxProductHw<IGFX_PTL> enableGfxProductHwPTL;
 #endif
 
 #ifdef SUPPORT_NVLS
+template <>
+uint32_t L1CachePolicyHelper<IGFX_NVL_XE3G>::getDefaultL1CachePolicy(bool isDebuggerActive) {
+    using GfxFamily = HwMapper<IGFX_NVL_XE3G>::GfxFamily;
+    if (isDebuggerActive) {
+        return GfxFamily::STATE_BASE_ADDRESS::L1_CACHE_CONTROL_WBP;
+    }
+    return GfxFamily::STATE_BASE_ADDRESS::L1_CACHE_CONTROL_WB;
+}
+
 template struct L1CachePolicyHelper<IGFX_NVL_XE3G>;
 static EnableGfxProductHw<IGFX_NVL_XE3G> enableGfxProductHwNVLS;
 #endif
