@@ -26,6 +26,7 @@ struct Xe3Core {
     static constexpr uint32_t stateComputeModeEuThreadSchedulingModeOverrideMask = (0b11u << 13);
     static constexpr uint32_t stateComputeModeLargeGrfModeMask = (1u << 15);
     // DW2
+    static constexpr uint32_t stateComputeModeUavCoherencyModeMask = (1u << 6);
     static constexpr uint32_t bcsEngineCount = 1u;
     static constexpr uint32_t timestampPacketCount = 16u;
 
@@ -55,6 +56,7 @@ struct Xe3Core {
 
         static constexpr bool allocationForScratchAndMidthreadPreemption = true;
         static constexpr bool enableVariableRegisterSizeAllocation = true;
+        static constexpr bool enableL1FlushUavCoherencyMode = true;
     };
 
     struct StateBaseAddressStateSupport {
@@ -151,6 +153,7 @@ struct Xe3CoreFamily : public Xe3Core {
     static const STATE_SYSTEM_MEM_FENCE_ADDRESS cmdInitStateSystemMemFenceAddress;
     static constexpr bool isQwordInOrderCounter = false;
     static constexpr bool walkerPostSyncSupport = true;
+    static constexpr bool samplerArbitrationControl = false;
     static constexpr size_t indirectDataAlignment = COMPUTE_WALKER::INDIRECTDATASTARTADDRESS_ALIGN_SIZE;
     static constexpr GFXCORE_FAMILY gfxCoreFamily = IGFX_XE3_CORE;
 
