@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2025 Intel Corporation
+ * Copyright (C) 2021-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -13,6 +13,7 @@
 using Family = NEO::XeHpcCoreFamily;
 
 #include "shared/source/command_stream/command_stream_receiver_hw_dg2_and_later.inl"
+#include "shared/source/command_stream/command_stream_receiver_hw_from_xe_hpc_to_xe3.inl"
 #include "shared/source/command_stream/command_stream_receiver_hw_heap_addressing.inl"
 #include "shared/source/command_stream/command_stream_receiver_hw_xehp_and_later.inl"
 #include "shared/source/gmm_helper/gmm.h"
@@ -38,26 +39,6 @@ void populateFactoryTable<CommandStreamReceiverHw<Family>>() {
     commandStreamReceiverFactory[gfxCore] = DeviceCommandStreamReceiver<Family>::create;
 }
 
-template <>
-void CommandStreamReceiverHw<Family>::programEnginePrologue(LinearStream &csr) {
-    if (!this->isEnginePrologueSent) {
-        if (getGlobalFenceAllocation()) {
-            EncodeMemoryFence<Family>::encodeSystemMemoryFence(csr, getGlobalFenceAllocation());
-        }
-        this->isEnginePrologueSent = true;
-    }
-}
-
-template <>
-size_t CommandStreamReceiverHw<Family>::getCmdSizeForPrologue() const {
-    if (!this->isEnginePrologueSent) {
-        if (getGlobalFenceAllocation()) {
-            return EncodeMemoryFence<Family>::getSystemMemoryFenceSize();
-        }
-    }
-    return 0u;
-}
-
 template <>
 void BlitCommandsHelper<Family>::appendBlitCommandsBlockCopy(const BlitProperties &blitProperties, typename Family::XY_BLOCK_COPY_BLT &blitCmd, const RootDeviceEnvironment &rootDeviceEnvironment) {
 }
@@ -119,21 +100,6 @@ void BlitCommandsHelper<Family>::appendBlitCommandsMemCopy(const BlitProperties
         }
     }
 
-    if (debugManager.flags.EnableStatelessCompressionWithUnifiedMemory.get()) {
-        if (srcAllocation) {
-            if (!MemoryPoolHelper::isSystemMemoryPool(srcAllocation->getMemoryPool())) {
-                blitCmd.setSourceCompressible(MEM_COPY::SOURCE_COMPRESSIBLE::SOURCE_COMPRESSIBLE_COMPRESSIBLE);
-                blitCmd.setCompressionFormat(debugManager.flags.FormatForStatelessCompressionWithUnifiedMemory.get());
-            }
-        }
-        if (dstAllocation) {
-            if (!MemoryPoolHelper::isSystemMemoryPool(dstAllocation->getMemoryPool())) {
-                blitCmd.setDestinationCompressible(MEM_COPY::DESTINATION_COMPRESSIBLE::DESTINATION_COMPRESSIBLE_COMPRESSIBLE);
-                blitCmd.setCompressionFormat(debugManager.flags.FormatForStatelessCompressionWithUnifiedMemory.get());
-            }
-        }
-    }
-
     if (blitCmd.getDestinationCompressible() == MEM_COPY::DESTINATION_COMPRESSIBLE::DESTINATION_COMPRESSIBLE_COMPRESSIBLE &&
         AuxTranslationDirection::auxToNonAux != blitProperties.auxTranslationDirection) {
         blitCmd.setDestinationCompressionEnable(MEM_COPY::DESTINATION_COMPRESSION_ENABLE::DESTINATION_COMPRESSION_ENABLE_ENABLE);
@@ -156,13 +122,6 @@ void BlitCommandsHelper<Family>::appendBlitMemSetCompressionFormat(void *blitCmd
         memSetCmd->setCompressionFormat40(compressionFormat);
     }
 
-    if (debugManager.flags.EnableStatelessCompressionWithUnifiedMemory.get()) {
-        if (!MemoryPoolHelper::isSystemMemoryPool(dstAlloc->getMemoryPool())) {
-            memSetCmd->setDestinationCompressible(MEM_SET::DESTINATION_COMPRESSIBLE::DESTINATION_COMPRESSIBLE_COMPRESSIBLE);
-            memSetCmd->setCompressionFormat40(debugManager.flags.FormatForStatelessCompressionWithUnifiedMemory.get());
-        }
-    }
-
     if (memSetCmd->getDestinationCompressible() == MEM_SET::DESTINATION_COMPRESSIBLE::DESTINATION_COMPRESSIBLE_COMPRESSIBLE) {
         memSetCmd->setDestinationCompressionEnable(MEM_SET::DESTINATION_COMPRESSION_ENABLE::DESTINATION_COMPRESSION_ENABLE_ENABLE);
     } else {
